// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/processing/processingModule.proto

#include "proto/processing/processingModule.pb.h"

#include <algorithm>

#include <google/protobuf/stubs/common.h>
#include <google/protobuf/stubs/port.h>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/wire_format_lite_inl.h>
#include <google/protobuf/descriptor.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/reflection_ops.h>
#include <google/protobuf/wire_format.h>
// This is a temporary google only hack
#ifdef GOOGLE_PROTOBUF_ENFORCE_UNIQUENESS
#include "third_party/protobuf/version.h"
#endif
// @@protoc_insertion_point(includes)

namespace protobuf_proto_2fprocessing_2fprocessingModule_2eproto {
extern PROTOBUF_INTERNAL_EXPORT_protobuf_proto_2fprocessing_2fprocessingModule_2eproto ::google::protobuf::internal::SCCInfo<0> scc_info_ModuleIO;
extern PROTOBUF_INTERNAL_EXPORT_protobuf_proto_2fprocessing_2fprocessingModule_2eproto ::google::protobuf::internal::SCCInfo<0> scc_info_ProcessingMode_Frequency;
extern PROTOBUF_INTERNAL_EXPORT_protobuf_proto_2fprocessing_2fprocessingModule_2eproto ::google::protobuf::internal::SCCInfo<0> scc_info_ProcessingMode_Lockstep;
extern PROTOBUF_INTERNAL_EXPORT_protobuf_proto_2fprocessing_2fprocessingModule_2eproto ::google::protobuf::internal::SCCInfo<0> scc_info_ProcessingMode_TriggerOnInput;
extern PROTOBUF_INTERNAL_EXPORT_protobuf_proto_2fprocessing_2fprocessingModule_2eproto ::google::protobuf::internal::SCCInfo<2> scc_info_ProcessingModule;
extern PROTOBUF_INTERNAL_EXPORT_protobuf_proto_2fprocessing_2fprocessingModule_2eproto ::google::protobuf::internal::SCCInfo<3> scc_info_ProcessingMode;
}  // namespace protobuf_proto_2fprocessing_2fprocessingModule_2eproto
namespace ubii {
namespace processing {
class ProcessingMode_FrequencyDefaultTypeInternal {
 public:
  ::google::protobuf::internal::ExplicitlyConstructed<ProcessingMode_Frequency>
      _instance;
} _ProcessingMode_Frequency_default_instance_;
class ProcessingMode_LockstepDefaultTypeInternal {
 public:
  ::google::protobuf::internal::ExplicitlyConstructed<ProcessingMode_Lockstep>
      _instance;
} _ProcessingMode_Lockstep_default_instance_;
class ProcessingMode_TriggerOnInputDefaultTypeInternal {
 public:
  ::google::protobuf::internal::ExplicitlyConstructed<ProcessingMode_TriggerOnInput>
      _instance;
} _ProcessingMode_TriggerOnInput_default_instance_;
class ProcessingModeDefaultTypeInternal {
 public:
  ::google::protobuf::internal::ExplicitlyConstructed<ProcessingMode>
      _instance;
  const ::ubii::processing::ProcessingMode_Frequency* frequency_;
  const ::ubii::processing::ProcessingMode_Lockstep* lockstep_;
  const ::ubii::processing::ProcessingMode_TriggerOnInput* trigger_on_input_;
} _ProcessingMode_default_instance_;
class ModuleIODefaultTypeInternal {
 public:
  ::google::protobuf::internal::ExplicitlyConstructed<ModuleIO>
      _instance;
} _ModuleIO_default_instance_;
class ProcessingModuleDefaultTypeInternal {
 public:
  ::google::protobuf::internal::ExplicitlyConstructed<ProcessingModule>
      _instance;
} _ProcessingModule_default_instance_;
class ProcessingModuleListDefaultTypeInternal {
 public:
  ::google::protobuf::internal::ExplicitlyConstructed<ProcessingModuleList>
      _instance;
} _ProcessingModuleList_default_instance_;
}  // namespace processing
}  // namespace ubii
namespace protobuf_proto_2fprocessing_2fprocessingModule_2eproto {
static void InitDefaultsProcessingMode_Frequency() {
  GOOGLE_PROTOBUF_VERIFY_VERSION;

  {
    void* ptr = &::ubii::processing::_ProcessingMode_Frequency_default_instance_;
    new (ptr) ::ubii::processing::ProcessingMode_Frequency();
    ::google::protobuf::internal::OnShutdownDestroyMessage(ptr);
  }
  ::ubii::processing::ProcessingMode_Frequency::InitAsDefaultInstance();
}

::google::protobuf::internal::SCCInfo<0> scc_info_ProcessingMode_Frequency =
    {{ATOMIC_VAR_INIT(::google::protobuf::internal::SCCInfoBase::kUninitialized), 0, InitDefaultsProcessingMode_Frequency}, {}};

static void InitDefaultsProcessingMode_Lockstep() {
  GOOGLE_PROTOBUF_VERIFY_VERSION;

  {
    void* ptr = &::ubii::processing::_ProcessingMode_Lockstep_default_instance_;
    new (ptr) ::ubii::processing::ProcessingMode_Lockstep();
    ::google::protobuf::internal::OnShutdownDestroyMessage(ptr);
  }
  ::ubii::processing::ProcessingMode_Lockstep::InitAsDefaultInstance();
}

::google::protobuf::internal::SCCInfo<0> scc_info_ProcessingMode_Lockstep =
    {{ATOMIC_VAR_INIT(::google::protobuf::internal::SCCInfoBase::kUninitialized), 0, InitDefaultsProcessingMode_Lockstep}, {}};

static void InitDefaultsProcessingMode_TriggerOnInput() {
  GOOGLE_PROTOBUF_VERIFY_VERSION;

  {
    void* ptr = &::ubii::processing::_ProcessingMode_TriggerOnInput_default_instance_;
    new (ptr) ::ubii::processing::ProcessingMode_TriggerOnInput();
    ::google::protobuf::internal::OnShutdownDestroyMessage(ptr);
  }
  ::ubii::processing::ProcessingMode_TriggerOnInput::InitAsDefaultInstance();
}

::google::protobuf::internal::SCCInfo<0> scc_info_ProcessingMode_TriggerOnInput =
    {{ATOMIC_VAR_INIT(::google::protobuf::internal::SCCInfoBase::kUninitialized), 0, InitDefaultsProcessingMode_TriggerOnInput}, {}};

static void InitDefaultsProcessingMode() {
  GOOGLE_PROTOBUF_VERIFY_VERSION;

  {
    void* ptr = &::ubii::processing::_ProcessingMode_default_instance_;
    new (ptr) ::ubii::processing::ProcessingMode();
    ::google::protobuf::internal::OnShutdownDestroyMessage(ptr);
  }
  ::ubii::processing::ProcessingMode::InitAsDefaultInstance();
}

::google::protobuf::internal::SCCInfo<3> scc_info_ProcessingMode =
    {{ATOMIC_VAR_INIT(::google::protobuf::internal::SCCInfoBase::kUninitialized), 3, InitDefaultsProcessingMode}, {
      &protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingMode_Frequency.base,
      &protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingMode_Lockstep.base,
      &protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingMode_TriggerOnInput.base,}};

static void InitDefaultsModuleIO() {
  GOOGLE_PROTOBUF_VERIFY_VERSION;

  {
    void* ptr = &::ubii::processing::_ModuleIO_default_instance_;
    new (ptr) ::ubii::processing::ModuleIO();
    ::google::protobuf::internal::OnShutdownDestroyMessage(ptr);
  }
  ::ubii::processing::ModuleIO::InitAsDefaultInstance();
}

::google::protobuf::internal::SCCInfo<0> scc_info_ModuleIO =
    {{ATOMIC_VAR_INIT(::google::protobuf::internal::SCCInfoBase::kUninitialized), 0, InitDefaultsModuleIO}, {}};

static void InitDefaultsProcessingModule() {
  GOOGLE_PROTOBUF_VERIFY_VERSION;

  {
    void* ptr = &::ubii::processing::_ProcessingModule_default_instance_;
    new (ptr) ::ubii::processing::ProcessingModule();
    ::google::protobuf::internal::OnShutdownDestroyMessage(ptr);
  }
  ::ubii::processing::ProcessingModule::InitAsDefaultInstance();
}

::google::protobuf::internal::SCCInfo<2> scc_info_ProcessingModule =
    {{ATOMIC_VAR_INIT(::google::protobuf::internal::SCCInfoBase::kUninitialized), 2, InitDefaultsProcessingModule}, {
      &protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingMode.base,
      &protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ModuleIO.base,}};

static void InitDefaultsProcessingModuleList() {
  GOOGLE_PROTOBUF_VERIFY_VERSION;

  {
    void* ptr = &::ubii::processing::_ProcessingModuleList_default_instance_;
    new (ptr) ::ubii::processing::ProcessingModuleList();
    ::google::protobuf::internal::OnShutdownDestroyMessage(ptr);
  }
  ::ubii::processing::ProcessingModuleList::InitAsDefaultInstance();
}

::google::protobuf::internal::SCCInfo<1> scc_info_ProcessingModuleList =
    {{ATOMIC_VAR_INIT(::google::protobuf::internal::SCCInfoBase::kUninitialized), 1, InitDefaultsProcessingModuleList}, {
      &protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingModule.base,}};

void InitDefaults() {
  ::google::protobuf::internal::InitSCC(&scc_info_ProcessingMode_Frequency.base);
  ::google::protobuf::internal::InitSCC(&scc_info_ProcessingMode_Lockstep.base);
  ::google::protobuf::internal::InitSCC(&scc_info_ProcessingMode_TriggerOnInput.base);
  ::google::protobuf::internal::InitSCC(&scc_info_ProcessingMode.base);
  ::google::protobuf::internal::InitSCC(&scc_info_ModuleIO.base);
  ::google::protobuf::internal::InitSCC(&scc_info_ProcessingModule.base);
  ::google::protobuf::internal::InitSCC(&scc_info_ProcessingModuleList.base);
}

::google::protobuf::Metadata file_level_metadata[7];
const ::google::protobuf::EnumDescriptor* file_level_enum_descriptors[2];

const ::google::protobuf::uint32 TableStruct::offsets[] GOOGLE_PROTOBUF_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
  ~0u,  // no _has_bits_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingMode_Frequency, _internal_metadata_),
  ~0u,  // no _extensions_
  ~0u,  // no _oneof_case_
  ~0u,  // no _weak_field_map_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingMode_Frequency, hertz_),
  ~0u,  // no _has_bits_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingMode_Lockstep, _internal_metadata_),
  ~0u,  // no _extensions_
  ~0u,  // no _oneof_case_
  ~0u,  // no _weak_field_map_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingMode_Lockstep, process_request_endpoint_),
  ~0u,  // no _has_bits_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingMode_TriggerOnInput, _internal_metadata_),
  ~0u,  // no _extensions_
  ~0u,  // no _oneof_case_
  ~0u,  // no _weak_field_map_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingMode_TriggerOnInput, min_delay_ms_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingMode_TriggerOnInput, all_inputs_need_update_),
  ~0u,  // no _has_bits_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingMode, _internal_metadata_),
  ~0u,  // no _extensions_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingMode, _oneof_case_[0]),
  ~0u,  // no _weak_field_map_
  offsetof(::ubii::processing::ProcessingModeDefaultTypeInternal, frequency_),
  offsetof(::ubii::processing::ProcessingModeDefaultTypeInternal, lockstep_),
  offsetof(::ubii::processing::ProcessingModeDefaultTypeInternal, trigger_on_input_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingMode, mode_),
  ~0u,  // no _has_bits_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ModuleIO, _internal_metadata_),
  ~0u,  // no _extensions_
  ~0u,  // no _oneof_case_
  ~0u,  // no _weak_field_map_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ModuleIO, internal_name_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ModuleIO, message_format_),
  ~0u,  // no _has_bits_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, _internal_metadata_),
  ~0u,  // no _extensions_
  ~0u,  // no _oneof_case_
  ~0u,  // no _weak_field_map_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, id_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, name_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, authors_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, tags_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, description_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, node_id_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, session_id_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, status_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, processing_mode_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, inputs_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, outputs_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, language_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, on_processing_stringified_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, on_created_stringified_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, on_halted_stringified_),
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModule, on_destroyed_stringified_),
  ~0u,  // no _has_bits_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModuleList, _internal_metadata_),
  ~0u,  // no _extensions_
  ~0u,  // no _oneof_case_
  ~0u,  // no _weak_field_map_
  GOOGLE_PROTOBUF_GENERATED_MESSAGE_FIELD_OFFSET(::ubii::processing::ProcessingModuleList, elements_),
};
static const ::google::protobuf::internal::MigrationSchema schemas[] GOOGLE_PROTOBUF_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
  { 0, -1, sizeof(::ubii::processing::ProcessingMode_Frequency)},
  { 6, -1, sizeof(::ubii::processing::ProcessingMode_Lockstep)},
  { 12, -1, sizeof(::ubii::processing::ProcessingMode_TriggerOnInput)},
  { 19, -1, sizeof(::ubii::processing::ProcessingMode)},
  { 28, -1, sizeof(::ubii::processing::ModuleIO)},
  { 35, -1, sizeof(::ubii::processing::ProcessingModule)},
  { 56, -1, sizeof(::ubii::processing::ProcessingModuleList)},
};

static ::google::protobuf::Message const * const file_default_instances[] = {
  reinterpret_cast<const ::google::protobuf::Message*>(&::ubii::processing::_ProcessingMode_Frequency_default_instance_),
  reinterpret_cast<const ::google::protobuf::Message*>(&::ubii::processing::_ProcessingMode_Lockstep_default_instance_),
  reinterpret_cast<const ::google::protobuf::Message*>(&::ubii::processing::_ProcessingMode_TriggerOnInput_default_instance_),
  reinterpret_cast<const ::google::protobuf::Message*>(&::ubii::processing::_ProcessingMode_default_instance_),
  reinterpret_cast<const ::google::protobuf::Message*>(&::ubii::processing::_ModuleIO_default_instance_),
  reinterpret_cast<const ::google::protobuf::Message*>(&::ubii::processing::_ProcessingModule_default_instance_),
  reinterpret_cast<const ::google::protobuf::Message*>(&::ubii::processing::_ProcessingModuleList_default_instance_),
};

void protobuf_AssignDescriptors() {
  AddDescriptors();
  AssignDescriptors(
      "proto/processing/processingModule.proto", schemas, file_default_instances, TableStruct::offsets,
      file_level_metadata, file_level_enum_descriptors, NULL);
}

void protobuf_AssignDescriptorsOnce() {
  static ::google::protobuf::internal::once_flag once;
  ::google::protobuf::internal::call_once(once, protobuf_AssignDescriptors);
}

void protobuf_RegisterTypes(const ::std::string&) GOOGLE_PROTOBUF_ATTRIBUTE_COLD;
void protobuf_RegisterTypes(const ::std::string&) {
  protobuf_AssignDescriptorsOnce();
  ::google::protobuf::internal::RegisterAllTypes(file_level_metadata, 7);
}

void AddDescriptorsImpl() {
  InitDefaults();
  static const char descriptor[] GOOGLE_PROTOBUF_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
      "\n\'proto/processing/processingModule.prot"
      "o\022\017ubii.processing\"\364\002\n\016ProcessingMode\022>\n"
      "\tfrequency\030\001 \001(\0132).ubii.processing.Proce"
      "ssingMode.FrequencyH\000\022<\n\010lockstep\030\002 \001(\0132"
      "(.ubii.processing.ProcessingMode.Lockste"
      "pH\000\022J\n\020trigger_on_input\030\003 \001(\0132..ubii.pro"
      "cessing.ProcessingMode.TriggerOnInputH\000\032"
      "\032\n\tFrequency\022\r\n\005hertz\030\001 \001(\005\032,\n\010Lockstep\022"
      " \n\030process_request_endpoint\030\001 \001(\t\032F\n\016Tri"
      "ggerOnInput\022\024\n\014min_delay_ms\030\001 \001(\005\022\036\n\026all"
      "_inputs_need_update\030\002 \001(\010B\006\n\004mode\"9\n\010Mod"
      "uleIO\022\025\n\rinternal_name\030\001 \001(\t\022\026\n\016message_"
      "format\030\002 \001(\t\"\234\005\n\020ProcessingModule\022\n\n\002id\030"
      "\001 \001(\t\022\014\n\004name\030\002 \001(\t\022\017\n\007authors\030\003 \003(\t\022\014\n\004"
      "tags\030\004 \003(\t\022\023\n\013description\030\005 \001(\t\022\017\n\007node_"
      "id\030\006 \001(\t\022\022\n\nsession_id\030\007 \001(\t\0228\n\006status\030\010"
      " \001(\0162(.ubii.processing.ProcessingModule."
      "Status\0228\n\017processing_mode\030\t \001(\0132\037.ubii.p"
      "rocessing.ProcessingMode\022)\n\006inputs\030\n \003(\013"
      "2\031.ubii.processing.ModuleIO\022*\n\007outputs\030\013"
      " \003(\0132\031.ubii.processing.ModuleIO\022<\n\010langu"
      "age\030\014 \001(\0162*.ubii.processing.ProcessingMo"
      "dule.Language\022!\n\031on_processing_stringifi"
      "ed\030\r \001(\t\022\036\n\026on_created_stringified\030\016 \001(\t"
      "\022\035\n\025on_halted_stringified\030\017 \001(\t\022 \n\030on_de"
      "stroyed_stringified\030\020 \001(\t\"Q\n\006Status\022\017\n\013I"
      "NITIALIZED\020\000\022\013\n\007CREATED\020\001\022\016\n\nPROCESSING\020"
      "\002\022\n\n\006HALTED\020\003\022\r\n\tDESTROYED\020\004\"5\n\010Language"
      "\022\007\n\003CPP\020\000\022\006\n\002PY\020\001\022\006\n\002JS\020\002\022\006\n\002CS\020\003\022\010\n\004JAV"
      "A\020\004\"K\n\024ProcessingModuleList\0223\n\010elements\030"
      "\001 \003(\0132!.ubii.processing.ProcessingModule"
      "b\006proto3"
  };
  ::google::protobuf::DescriptorPool::InternalAddGeneratedFile(
      descriptor, 1248);
  ::google::protobuf::MessageFactory::InternalRegisterGeneratedFile(
    "proto/processing/processingModule.proto", &protobuf_RegisterTypes);
}

void AddDescriptors() {
  static ::google::protobuf::internal::once_flag once;
  ::google::protobuf::internal::call_once(once, AddDescriptorsImpl);
}
// Force AddDescriptors() to be called at dynamic initialization time.
struct StaticDescriptorInitializer {
  StaticDescriptorInitializer() {
    AddDescriptors();
  }
} static_descriptor_initializer;
}  // namespace protobuf_proto_2fprocessing_2fprocessingModule_2eproto
namespace ubii {
namespace processing {
const ::google::protobuf::EnumDescriptor* ProcessingModule_Status_descriptor() {
  protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_enum_descriptors[0];
}
bool ProcessingModule_Status_IsValid(int value) {
  switch (value) {
    case 0:
    case 1:
    case 2:
    case 3:
    case 4:
      return true;
    default:
      return false;
  }
}

#if !defined(_MSC_VER) || _MSC_VER >= 1900
const ProcessingModule_Status ProcessingModule::INITIALIZED;
const ProcessingModule_Status ProcessingModule::CREATED;
const ProcessingModule_Status ProcessingModule::PROCESSING;
const ProcessingModule_Status ProcessingModule::HALTED;
const ProcessingModule_Status ProcessingModule::DESTROYED;
const ProcessingModule_Status ProcessingModule::Status_MIN;
const ProcessingModule_Status ProcessingModule::Status_MAX;
const int ProcessingModule::Status_ARRAYSIZE;
#endif  // !defined(_MSC_VER) || _MSC_VER >= 1900
const ::google::protobuf::EnumDescriptor* ProcessingModule_Language_descriptor() {
  protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_enum_descriptors[1];
}
bool ProcessingModule_Language_IsValid(int value) {
  switch (value) {
    case 0:
    case 1:
    case 2:
    case 3:
    case 4:
      return true;
    default:
      return false;
  }
}

#if !defined(_MSC_VER) || _MSC_VER >= 1900
const ProcessingModule_Language ProcessingModule::CPP;
const ProcessingModule_Language ProcessingModule::PY;
const ProcessingModule_Language ProcessingModule::JS;
const ProcessingModule_Language ProcessingModule::CS;
const ProcessingModule_Language ProcessingModule::JAVA;
const ProcessingModule_Language ProcessingModule::Language_MIN;
const ProcessingModule_Language ProcessingModule::Language_MAX;
const int ProcessingModule::Language_ARRAYSIZE;
#endif  // !defined(_MSC_VER) || _MSC_VER >= 1900

// ===================================================================

void ProcessingMode_Frequency::InitAsDefaultInstance() {
}
#if !defined(_MSC_VER) || _MSC_VER >= 1900
const int ProcessingMode_Frequency::kHertzFieldNumber;
#endif  // !defined(_MSC_VER) || _MSC_VER >= 1900

ProcessingMode_Frequency::ProcessingMode_Frequency()
  : ::google::protobuf::Message(), _internal_metadata_(NULL) {
  ::google::protobuf::internal::InitSCC(
      &protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingMode_Frequency.base);
  SharedCtor();
  // @@protoc_insertion_point(constructor:ubii.processing.ProcessingMode.Frequency)
}
ProcessingMode_Frequency::ProcessingMode_Frequency(const ProcessingMode_Frequency& from)
  : ::google::protobuf::Message(),
      _internal_metadata_(NULL) {
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  hertz_ = from.hertz_;
  // @@protoc_insertion_point(copy_constructor:ubii.processing.ProcessingMode.Frequency)
}

void ProcessingMode_Frequency::SharedCtor() {
  hertz_ = 0;
}

ProcessingMode_Frequency::~ProcessingMode_Frequency() {
  // @@protoc_insertion_point(destructor:ubii.processing.ProcessingMode.Frequency)
  SharedDtor();
}

void ProcessingMode_Frequency::SharedDtor() {
}

void ProcessingMode_Frequency::SetCachedSize(int size) const {
  _cached_size_.Set(size);
}
const ::google::protobuf::Descriptor* ProcessingMode_Frequency::descriptor() {
  ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages].descriptor;
}

const ProcessingMode_Frequency& ProcessingMode_Frequency::default_instance() {
  ::google::protobuf::internal::InitSCC(&protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingMode_Frequency.base);
  return *internal_default_instance();
}


void ProcessingMode_Frequency::Clear() {
// @@protoc_insertion_point(message_clear_start:ubii.processing.ProcessingMode.Frequency)
  ::google::protobuf::uint32 cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  hertz_ = 0;
  _internal_metadata_.Clear();
}

bool ProcessingMode_Frequency::MergePartialFromCodedStream(
    ::google::protobuf::io::CodedInputStream* input) {
#define DO_(EXPRESSION) if (!GOOGLE_PREDICT_TRUE(EXPRESSION)) goto failure
  ::google::protobuf::uint32 tag;
  // @@protoc_insertion_point(parse_start:ubii.processing.ProcessingMode.Frequency)
  for (;;) {
    ::std::pair<::google::protobuf::uint32, bool> p = input->ReadTagWithCutoffNoLastTag(127u);
    tag = p.first;
    if (!p.second) goto handle_unusual;
    switch (::google::protobuf::internal::WireFormatLite::GetTagFieldNumber(tag)) {
      // int32 hertz = 1;
      case 1: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(8u /* 8 & 0xFF */)) {

          DO_((::google::protobuf::internal::WireFormatLite::ReadPrimitive<
                   ::google::protobuf::int32, ::google::protobuf::internal::WireFormatLite::TYPE_INT32>(
                 input, &hertz_)));
        } else {
          goto handle_unusual;
        }
        break;
      }

      default: {
      handle_unusual:
        if (tag == 0) {
          goto success;
        }
        DO_(::google::protobuf::internal::WireFormat::SkipField(
              input, tag, _internal_metadata_.mutable_unknown_fields()));
        break;
      }
    }
  }
success:
  // @@protoc_insertion_point(parse_success:ubii.processing.ProcessingMode.Frequency)
  return true;
failure:
  // @@protoc_insertion_point(parse_failure:ubii.processing.ProcessingMode.Frequency)
  return false;
#undef DO_
}

void ProcessingMode_Frequency::SerializeWithCachedSizes(
    ::google::protobuf::io::CodedOutputStream* output) const {
  // @@protoc_insertion_point(serialize_start:ubii.processing.ProcessingMode.Frequency)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // int32 hertz = 1;
  if (this->hertz() != 0) {
    ::google::protobuf::internal::WireFormatLite::WriteInt32(1, this->hertz(), output);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    ::google::protobuf::internal::WireFormat::SerializeUnknownFields(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), output);
  }
  // @@protoc_insertion_point(serialize_end:ubii.processing.ProcessingMode.Frequency)
}

::google::protobuf::uint8* ProcessingMode_Frequency::InternalSerializeWithCachedSizesToArray(
    bool deterministic, ::google::protobuf::uint8* target) const {
  (void)deterministic; // Unused
  // @@protoc_insertion_point(serialize_to_array_start:ubii.processing.ProcessingMode.Frequency)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // int32 hertz = 1;
  if (this->hertz() != 0) {
    target = ::google::protobuf::internal::WireFormatLite::WriteInt32ToArray(1, this->hertz(), target);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    target = ::google::protobuf::internal::WireFormat::SerializeUnknownFieldsToArray(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:ubii.processing.ProcessingMode.Frequency)
  return target;
}

size_t ProcessingMode_Frequency::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:ubii.processing.ProcessingMode.Frequency)
  size_t total_size = 0;

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    total_size +=
      ::google::protobuf::internal::WireFormat::ComputeUnknownFieldsSize(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()));
  }
  // int32 hertz = 1;
  if (this->hertz() != 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::Int32Size(
        this->hertz());
  }

  int cached_size = ::google::protobuf::internal::ToCachedSize(total_size);
  SetCachedSize(cached_size);
  return total_size;
}

void ProcessingMode_Frequency::MergeFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_merge_from_start:ubii.processing.ProcessingMode.Frequency)
  GOOGLE_DCHECK_NE(&from, this);
  const ProcessingMode_Frequency* source =
      ::google::protobuf::internal::DynamicCastToGenerated<const ProcessingMode_Frequency>(
          &from);
  if (source == NULL) {
  // @@protoc_insertion_point(generalized_merge_from_cast_fail:ubii.processing.ProcessingMode.Frequency)
    ::google::protobuf::internal::ReflectionOps::Merge(from, this);
  } else {
  // @@protoc_insertion_point(generalized_merge_from_cast_success:ubii.processing.ProcessingMode.Frequency)
    MergeFrom(*source);
  }
}

void ProcessingMode_Frequency::MergeFrom(const ProcessingMode_Frequency& from) {
// @@protoc_insertion_point(class_specific_merge_from_start:ubii.processing.ProcessingMode.Frequency)
  GOOGLE_DCHECK_NE(&from, this);
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  if (from.hertz() != 0) {
    set_hertz(from.hertz());
  }
}

void ProcessingMode_Frequency::CopyFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_copy_from_start:ubii.processing.ProcessingMode.Frequency)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

void ProcessingMode_Frequency::CopyFrom(const ProcessingMode_Frequency& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:ubii.processing.ProcessingMode.Frequency)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool ProcessingMode_Frequency::IsInitialized() const {
  return true;
}

void ProcessingMode_Frequency::Swap(ProcessingMode_Frequency* other) {
  if (other == this) return;
  InternalSwap(other);
}
void ProcessingMode_Frequency::InternalSwap(ProcessingMode_Frequency* other) {
  using std::swap;
  swap(hertz_, other->hertz_);
  _internal_metadata_.Swap(&other->_internal_metadata_);
}

::google::protobuf::Metadata ProcessingMode_Frequency::GetMetadata() const {
  protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages];
}


// ===================================================================

void ProcessingMode_Lockstep::InitAsDefaultInstance() {
}
#if !defined(_MSC_VER) || _MSC_VER >= 1900
const int ProcessingMode_Lockstep::kProcessRequestEndpointFieldNumber;
#endif  // !defined(_MSC_VER) || _MSC_VER >= 1900

ProcessingMode_Lockstep::ProcessingMode_Lockstep()
  : ::google::protobuf::Message(), _internal_metadata_(NULL) {
  ::google::protobuf::internal::InitSCC(
      &protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingMode_Lockstep.base);
  SharedCtor();
  // @@protoc_insertion_point(constructor:ubii.processing.ProcessingMode.Lockstep)
}
ProcessingMode_Lockstep::ProcessingMode_Lockstep(const ProcessingMode_Lockstep& from)
  : ::google::protobuf::Message(),
      _internal_metadata_(NULL) {
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  process_request_endpoint_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (from.process_request_endpoint().size() > 0) {
    process_request_endpoint_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.process_request_endpoint_);
  }
  // @@protoc_insertion_point(copy_constructor:ubii.processing.ProcessingMode.Lockstep)
}

void ProcessingMode_Lockstep::SharedCtor() {
  process_request_endpoint_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}

ProcessingMode_Lockstep::~ProcessingMode_Lockstep() {
  // @@protoc_insertion_point(destructor:ubii.processing.ProcessingMode.Lockstep)
  SharedDtor();
}

void ProcessingMode_Lockstep::SharedDtor() {
  process_request_endpoint_.DestroyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}

void ProcessingMode_Lockstep::SetCachedSize(int size) const {
  _cached_size_.Set(size);
}
const ::google::protobuf::Descriptor* ProcessingMode_Lockstep::descriptor() {
  ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages].descriptor;
}

const ProcessingMode_Lockstep& ProcessingMode_Lockstep::default_instance() {
  ::google::protobuf::internal::InitSCC(&protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingMode_Lockstep.base);
  return *internal_default_instance();
}


void ProcessingMode_Lockstep::Clear() {
// @@protoc_insertion_point(message_clear_start:ubii.processing.ProcessingMode.Lockstep)
  ::google::protobuf::uint32 cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  process_request_endpoint_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  _internal_metadata_.Clear();
}

bool ProcessingMode_Lockstep::MergePartialFromCodedStream(
    ::google::protobuf::io::CodedInputStream* input) {
#define DO_(EXPRESSION) if (!GOOGLE_PREDICT_TRUE(EXPRESSION)) goto failure
  ::google::protobuf::uint32 tag;
  // @@protoc_insertion_point(parse_start:ubii.processing.ProcessingMode.Lockstep)
  for (;;) {
    ::std::pair<::google::protobuf::uint32, bool> p = input->ReadTagWithCutoffNoLastTag(127u);
    tag = p.first;
    if (!p.second) goto handle_unusual;
    switch (::google::protobuf::internal::WireFormatLite::GetTagFieldNumber(tag)) {
      // string process_request_endpoint = 1;
      case 1: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(10u /* 10 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->mutable_process_request_endpoint()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->process_request_endpoint().data(), static_cast<int>(this->process_request_endpoint().length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ProcessingMode.Lockstep.process_request_endpoint"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      default: {
      handle_unusual:
        if (tag == 0) {
          goto success;
        }
        DO_(::google::protobuf::internal::WireFormat::SkipField(
              input, tag, _internal_metadata_.mutable_unknown_fields()));
        break;
      }
    }
  }
success:
  // @@protoc_insertion_point(parse_success:ubii.processing.ProcessingMode.Lockstep)
  return true;
failure:
  // @@protoc_insertion_point(parse_failure:ubii.processing.ProcessingMode.Lockstep)
  return false;
#undef DO_
}

void ProcessingMode_Lockstep::SerializeWithCachedSizes(
    ::google::protobuf::io::CodedOutputStream* output) const {
  // @@protoc_insertion_point(serialize_start:ubii.processing.ProcessingMode.Lockstep)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // string process_request_endpoint = 1;
  if (this->process_request_endpoint().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->process_request_endpoint().data(), static_cast<int>(this->process_request_endpoint().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingMode.Lockstep.process_request_endpoint");
    ::google::protobuf::internal::WireFormatLite::WriteStringMaybeAliased(
      1, this->process_request_endpoint(), output);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    ::google::protobuf::internal::WireFormat::SerializeUnknownFields(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), output);
  }
  // @@protoc_insertion_point(serialize_end:ubii.processing.ProcessingMode.Lockstep)
}

::google::protobuf::uint8* ProcessingMode_Lockstep::InternalSerializeWithCachedSizesToArray(
    bool deterministic, ::google::protobuf::uint8* target) const {
  (void)deterministic; // Unused
  // @@protoc_insertion_point(serialize_to_array_start:ubii.processing.ProcessingMode.Lockstep)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // string process_request_endpoint = 1;
  if (this->process_request_endpoint().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->process_request_endpoint().data(), static_cast<int>(this->process_request_endpoint().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingMode.Lockstep.process_request_endpoint");
    target =
      ::google::protobuf::internal::WireFormatLite::WriteStringToArray(
        1, this->process_request_endpoint(), target);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    target = ::google::protobuf::internal::WireFormat::SerializeUnknownFieldsToArray(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:ubii.processing.ProcessingMode.Lockstep)
  return target;
}

size_t ProcessingMode_Lockstep::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:ubii.processing.ProcessingMode.Lockstep)
  size_t total_size = 0;

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    total_size +=
      ::google::protobuf::internal::WireFormat::ComputeUnknownFieldsSize(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()));
  }
  // string process_request_endpoint = 1;
  if (this->process_request_endpoint().size() > 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::StringSize(
        this->process_request_endpoint());
  }

  int cached_size = ::google::protobuf::internal::ToCachedSize(total_size);
  SetCachedSize(cached_size);
  return total_size;
}

void ProcessingMode_Lockstep::MergeFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_merge_from_start:ubii.processing.ProcessingMode.Lockstep)
  GOOGLE_DCHECK_NE(&from, this);
  const ProcessingMode_Lockstep* source =
      ::google::protobuf::internal::DynamicCastToGenerated<const ProcessingMode_Lockstep>(
          &from);
  if (source == NULL) {
  // @@protoc_insertion_point(generalized_merge_from_cast_fail:ubii.processing.ProcessingMode.Lockstep)
    ::google::protobuf::internal::ReflectionOps::Merge(from, this);
  } else {
  // @@protoc_insertion_point(generalized_merge_from_cast_success:ubii.processing.ProcessingMode.Lockstep)
    MergeFrom(*source);
  }
}

void ProcessingMode_Lockstep::MergeFrom(const ProcessingMode_Lockstep& from) {
// @@protoc_insertion_point(class_specific_merge_from_start:ubii.processing.ProcessingMode.Lockstep)
  GOOGLE_DCHECK_NE(&from, this);
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  if (from.process_request_endpoint().size() > 0) {

    process_request_endpoint_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.process_request_endpoint_);
  }
}

void ProcessingMode_Lockstep::CopyFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_copy_from_start:ubii.processing.ProcessingMode.Lockstep)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

void ProcessingMode_Lockstep::CopyFrom(const ProcessingMode_Lockstep& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:ubii.processing.ProcessingMode.Lockstep)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool ProcessingMode_Lockstep::IsInitialized() const {
  return true;
}

void ProcessingMode_Lockstep::Swap(ProcessingMode_Lockstep* other) {
  if (other == this) return;
  InternalSwap(other);
}
void ProcessingMode_Lockstep::InternalSwap(ProcessingMode_Lockstep* other) {
  using std::swap;
  process_request_endpoint_.Swap(&other->process_request_endpoint_, &::google::protobuf::internal::GetEmptyStringAlreadyInited(),
    GetArenaNoVirtual());
  _internal_metadata_.Swap(&other->_internal_metadata_);
}

::google::protobuf::Metadata ProcessingMode_Lockstep::GetMetadata() const {
  protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages];
}


// ===================================================================

void ProcessingMode_TriggerOnInput::InitAsDefaultInstance() {
}
#if !defined(_MSC_VER) || _MSC_VER >= 1900
const int ProcessingMode_TriggerOnInput::kMinDelayMsFieldNumber;
const int ProcessingMode_TriggerOnInput::kAllInputsNeedUpdateFieldNumber;
#endif  // !defined(_MSC_VER) || _MSC_VER >= 1900

ProcessingMode_TriggerOnInput::ProcessingMode_TriggerOnInput()
  : ::google::protobuf::Message(), _internal_metadata_(NULL) {
  ::google::protobuf::internal::InitSCC(
      &protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingMode_TriggerOnInput.base);
  SharedCtor();
  // @@protoc_insertion_point(constructor:ubii.processing.ProcessingMode.TriggerOnInput)
}
ProcessingMode_TriggerOnInput::ProcessingMode_TriggerOnInput(const ProcessingMode_TriggerOnInput& from)
  : ::google::protobuf::Message(),
      _internal_metadata_(NULL) {
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  ::memcpy(&min_delay_ms_, &from.min_delay_ms_,
    static_cast<size_t>(reinterpret_cast<char*>(&all_inputs_need_update_) -
    reinterpret_cast<char*>(&min_delay_ms_)) + sizeof(all_inputs_need_update_));
  // @@protoc_insertion_point(copy_constructor:ubii.processing.ProcessingMode.TriggerOnInput)
}

void ProcessingMode_TriggerOnInput::SharedCtor() {
  ::memset(&min_delay_ms_, 0, static_cast<size_t>(
      reinterpret_cast<char*>(&all_inputs_need_update_) -
      reinterpret_cast<char*>(&min_delay_ms_)) + sizeof(all_inputs_need_update_));
}

ProcessingMode_TriggerOnInput::~ProcessingMode_TriggerOnInput() {
  // @@protoc_insertion_point(destructor:ubii.processing.ProcessingMode.TriggerOnInput)
  SharedDtor();
}

void ProcessingMode_TriggerOnInput::SharedDtor() {
}

void ProcessingMode_TriggerOnInput::SetCachedSize(int size) const {
  _cached_size_.Set(size);
}
const ::google::protobuf::Descriptor* ProcessingMode_TriggerOnInput::descriptor() {
  ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages].descriptor;
}

const ProcessingMode_TriggerOnInput& ProcessingMode_TriggerOnInput::default_instance() {
  ::google::protobuf::internal::InitSCC(&protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingMode_TriggerOnInput.base);
  return *internal_default_instance();
}


void ProcessingMode_TriggerOnInput::Clear() {
// @@protoc_insertion_point(message_clear_start:ubii.processing.ProcessingMode.TriggerOnInput)
  ::google::protobuf::uint32 cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  ::memset(&min_delay_ms_, 0, static_cast<size_t>(
      reinterpret_cast<char*>(&all_inputs_need_update_) -
      reinterpret_cast<char*>(&min_delay_ms_)) + sizeof(all_inputs_need_update_));
  _internal_metadata_.Clear();
}

bool ProcessingMode_TriggerOnInput::MergePartialFromCodedStream(
    ::google::protobuf::io::CodedInputStream* input) {
#define DO_(EXPRESSION) if (!GOOGLE_PREDICT_TRUE(EXPRESSION)) goto failure
  ::google::protobuf::uint32 tag;
  // @@protoc_insertion_point(parse_start:ubii.processing.ProcessingMode.TriggerOnInput)
  for (;;) {
    ::std::pair<::google::protobuf::uint32, bool> p = input->ReadTagWithCutoffNoLastTag(127u);
    tag = p.first;
    if (!p.second) goto handle_unusual;
    switch (::google::protobuf::internal::WireFormatLite::GetTagFieldNumber(tag)) {
      // int32 min_delay_ms = 1;
      case 1: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(8u /* 8 & 0xFF */)) {

          DO_((::google::protobuf::internal::WireFormatLite::ReadPrimitive<
                   ::google::protobuf::int32, ::google::protobuf::internal::WireFormatLite::TYPE_INT32>(
                 input, &min_delay_ms_)));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // bool all_inputs_need_update = 2;
      case 2: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(16u /* 16 & 0xFF */)) {

          DO_((::google::protobuf::internal::WireFormatLite::ReadPrimitive<
                   bool, ::google::protobuf::internal::WireFormatLite::TYPE_BOOL>(
                 input, &all_inputs_need_update_)));
        } else {
          goto handle_unusual;
        }
        break;
      }

      default: {
      handle_unusual:
        if (tag == 0) {
          goto success;
        }
        DO_(::google::protobuf::internal::WireFormat::SkipField(
              input, tag, _internal_metadata_.mutable_unknown_fields()));
        break;
      }
    }
  }
success:
  // @@protoc_insertion_point(parse_success:ubii.processing.ProcessingMode.TriggerOnInput)
  return true;
failure:
  // @@protoc_insertion_point(parse_failure:ubii.processing.ProcessingMode.TriggerOnInput)
  return false;
#undef DO_
}

void ProcessingMode_TriggerOnInput::SerializeWithCachedSizes(
    ::google::protobuf::io::CodedOutputStream* output) const {
  // @@protoc_insertion_point(serialize_start:ubii.processing.ProcessingMode.TriggerOnInput)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // int32 min_delay_ms = 1;
  if (this->min_delay_ms() != 0) {
    ::google::protobuf::internal::WireFormatLite::WriteInt32(1, this->min_delay_ms(), output);
  }

  // bool all_inputs_need_update = 2;
  if (this->all_inputs_need_update() != 0) {
    ::google::protobuf::internal::WireFormatLite::WriteBool(2, this->all_inputs_need_update(), output);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    ::google::protobuf::internal::WireFormat::SerializeUnknownFields(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), output);
  }
  // @@protoc_insertion_point(serialize_end:ubii.processing.ProcessingMode.TriggerOnInput)
}

::google::protobuf::uint8* ProcessingMode_TriggerOnInput::InternalSerializeWithCachedSizesToArray(
    bool deterministic, ::google::protobuf::uint8* target) const {
  (void)deterministic; // Unused
  // @@protoc_insertion_point(serialize_to_array_start:ubii.processing.ProcessingMode.TriggerOnInput)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // int32 min_delay_ms = 1;
  if (this->min_delay_ms() != 0) {
    target = ::google::protobuf::internal::WireFormatLite::WriteInt32ToArray(1, this->min_delay_ms(), target);
  }

  // bool all_inputs_need_update = 2;
  if (this->all_inputs_need_update() != 0) {
    target = ::google::protobuf::internal::WireFormatLite::WriteBoolToArray(2, this->all_inputs_need_update(), target);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    target = ::google::protobuf::internal::WireFormat::SerializeUnknownFieldsToArray(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:ubii.processing.ProcessingMode.TriggerOnInput)
  return target;
}

size_t ProcessingMode_TriggerOnInput::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:ubii.processing.ProcessingMode.TriggerOnInput)
  size_t total_size = 0;

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    total_size +=
      ::google::protobuf::internal::WireFormat::ComputeUnknownFieldsSize(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()));
  }
  // int32 min_delay_ms = 1;
  if (this->min_delay_ms() != 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::Int32Size(
        this->min_delay_ms());
  }

  // bool all_inputs_need_update = 2;
  if (this->all_inputs_need_update() != 0) {
    total_size += 1 + 1;
  }

  int cached_size = ::google::protobuf::internal::ToCachedSize(total_size);
  SetCachedSize(cached_size);
  return total_size;
}

void ProcessingMode_TriggerOnInput::MergeFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_merge_from_start:ubii.processing.ProcessingMode.TriggerOnInput)
  GOOGLE_DCHECK_NE(&from, this);
  const ProcessingMode_TriggerOnInput* source =
      ::google::protobuf::internal::DynamicCastToGenerated<const ProcessingMode_TriggerOnInput>(
          &from);
  if (source == NULL) {
  // @@protoc_insertion_point(generalized_merge_from_cast_fail:ubii.processing.ProcessingMode.TriggerOnInput)
    ::google::protobuf::internal::ReflectionOps::Merge(from, this);
  } else {
  // @@protoc_insertion_point(generalized_merge_from_cast_success:ubii.processing.ProcessingMode.TriggerOnInput)
    MergeFrom(*source);
  }
}

void ProcessingMode_TriggerOnInput::MergeFrom(const ProcessingMode_TriggerOnInput& from) {
// @@protoc_insertion_point(class_specific_merge_from_start:ubii.processing.ProcessingMode.TriggerOnInput)
  GOOGLE_DCHECK_NE(&from, this);
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  if (from.min_delay_ms() != 0) {
    set_min_delay_ms(from.min_delay_ms());
  }
  if (from.all_inputs_need_update() != 0) {
    set_all_inputs_need_update(from.all_inputs_need_update());
  }
}

void ProcessingMode_TriggerOnInput::CopyFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_copy_from_start:ubii.processing.ProcessingMode.TriggerOnInput)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

void ProcessingMode_TriggerOnInput::CopyFrom(const ProcessingMode_TriggerOnInput& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:ubii.processing.ProcessingMode.TriggerOnInput)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool ProcessingMode_TriggerOnInput::IsInitialized() const {
  return true;
}

void ProcessingMode_TriggerOnInput::Swap(ProcessingMode_TriggerOnInput* other) {
  if (other == this) return;
  InternalSwap(other);
}
void ProcessingMode_TriggerOnInput::InternalSwap(ProcessingMode_TriggerOnInput* other) {
  using std::swap;
  swap(min_delay_ms_, other->min_delay_ms_);
  swap(all_inputs_need_update_, other->all_inputs_need_update_);
  _internal_metadata_.Swap(&other->_internal_metadata_);
}

::google::protobuf::Metadata ProcessingMode_TriggerOnInput::GetMetadata() const {
  protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages];
}


// ===================================================================

void ProcessingMode::InitAsDefaultInstance() {
  ::ubii::processing::_ProcessingMode_default_instance_.frequency_ = const_cast< ::ubii::processing::ProcessingMode_Frequency*>(
      ::ubii::processing::ProcessingMode_Frequency::internal_default_instance());
  ::ubii::processing::_ProcessingMode_default_instance_.lockstep_ = const_cast< ::ubii::processing::ProcessingMode_Lockstep*>(
      ::ubii::processing::ProcessingMode_Lockstep::internal_default_instance());
  ::ubii::processing::_ProcessingMode_default_instance_.trigger_on_input_ = const_cast< ::ubii::processing::ProcessingMode_TriggerOnInput*>(
      ::ubii::processing::ProcessingMode_TriggerOnInput::internal_default_instance());
}
void ProcessingMode::set_allocated_frequency(::ubii::processing::ProcessingMode_Frequency* frequency) {
  ::google::protobuf::Arena* message_arena = GetArenaNoVirtual();
  clear_mode();
  if (frequency) {
    ::google::protobuf::Arena* submessage_arena = NULL;
    if (message_arena != submessage_arena) {
      frequency = ::google::protobuf::internal::GetOwnedMessage(
          message_arena, frequency, submessage_arena);
    }
    set_has_frequency();
    mode_.frequency_ = frequency;
  }
  // @@protoc_insertion_point(field_set_allocated:ubii.processing.ProcessingMode.frequency)
}
void ProcessingMode::set_allocated_lockstep(::ubii::processing::ProcessingMode_Lockstep* lockstep) {
  ::google::protobuf::Arena* message_arena = GetArenaNoVirtual();
  clear_mode();
  if (lockstep) {
    ::google::protobuf::Arena* submessage_arena = NULL;
    if (message_arena != submessage_arena) {
      lockstep = ::google::protobuf::internal::GetOwnedMessage(
          message_arena, lockstep, submessage_arena);
    }
    set_has_lockstep();
    mode_.lockstep_ = lockstep;
  }
  // @@protoc_insertion_point(field_set_allocated:ubii.processing.ProcessingMode.lockstep)
}
void ProcessingMode::set_allocated_trigger_on_input(::ubii::processing::ProcessingMode_TriggerOnInput* trigger_on_input) {
  ::google::protobuf::Arena* message_arena = GetArenaNoVirtual();
  clear_mode();
  if (trigger_on_input) {
    ::google::protobuf::Arena* submessage_arena = NULL;
    if (message_arena != submessage_arena) {
      trigger_on_input = ::google::protobuf::internal::GetOwnedMessage(
          message_arena, trigger_on_input, submessage_arena);
    }
    set_has_trigger_on_input();
    mode_.trigger_on_input_ = trigger_on_input;
  }
  // @@protoc_insertion_point(field_set_allocated:ubii.processing.ProcessingMode.trigger_on_input)
}
#if !defined(_MSC_VER) || _MSC_VER >= 1900
const int ProcessingMode::kFrequencyFieldNumber;
const int ProcessingMode::kLockstepFieldNumber;
const int ProcessingMode::kTriggerOnInputFieldNumber;
#endif  // !defined(_MSC_VER) || _MSC_VER >= 1900

ProcessingMode::ProcessingMode()
  : ::google::protobuf::Message(), _internal_metadata_(NULL) {
  ::google::protobuf::internal::InitSCC(
      &protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingMode.base);
  SharedCtor();
  // @@protoc_insertion_point(constructor:ubii.processing.ProcessingMode)
}
ProcessingMode::ProcessingMode(const ProcessingMode& from)
  : ::google::protobuf::Message(),
      _internal_metadata_(NULL) {
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  clear_has_mode();
  switch (from.mode_case()) {
    case kFrequency: {
      mutable_frequency()->::ubii::processing::ProcessingMode_Frequency::MergeFrom(from.frequency());
      break;
    }
    case kLockstep: {
      mutable_lockstep()->::ubii::processing::ProcessingMode_Lockstep::MergeFrom(from.lockstep());
      break;
    }
    case kTriggerOnInput: {
      mutable_trigger_on_input()->::ubii::processing::ProcessingMode_TriggerOnInput::MergeFrom(from.trigger_on_input());
      break;
    }
    case MODE_NOT_SET: {
      break;
    }
  }
  // @@protoc_insertion_point(copy_constructor:ubii.processing.ProcessingMode)
}

void ProcessingMode::SharedCtor() {
  clear_has_mode();
}

ProcessingMode::~ProcessingMode() {
  // @@protoc_insertion_point(destructor:ubii.processing.ProcessingMode)
  SharedDtor();
}

void ProcessingMode::SharedDtor() {
  if (has_mode()) {
    clear_mode();
  }
}

void ProcessingMode::SetCachedSize(int size) const {
  _cached_size_.Set(size);
}
const ::google::protobuf::Descriptor* ProcessingMode::descriptor() {
  ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages].descriptor;
}

const ProcessingMode& ProcessingMode::default_instance() {
  ::google::protobuf::internal::InitSCC(&protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingMode.base);
  return *internal_default_instance();
}


void ProcessingMode::clear_mode() {
// @@protoc_insertion_point(one_of_clear_start:ubii.processing.ProcessingMode)
  switch (mode_case()) {
    case kFrequency: {
      delete mode_.frequency_;
      break;
    }
    case kLockstep: {
      delete mode_.lockstep_;
      break;
    }
    case kTriggerOnInput: {
      delete mode_.trigger_on_input_;
      break;
    }
    case MODE_NOT_SET: {
      break;
    }
  }
  _oneof_case_[0] = MODE_NOT_SET;
}


void ProcessingMode::Clear() {
// @@protoc_insertion_point(message_clear_start:ubii.processing.ProcessingMode)
  ::google::protobuf::uint32 cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  clear_mode();
  _internal_metadata_.Clear();
}

bool ProcessingMode::MergePartialFromCodedStream(
    ::google::protobuf::io::CodedInputStream* input) {
#define DO_(EXPRESSION) if (!GOOGLE_PREDICT_TRUE(EXPRESSION)) goto failure
  ::google::protobuf::uint32 tag;
  // @@protoc_insertion_point(parse_start:ubii.processing.ProcessingMode)
  for (;;) {
    ::std::pair<::google::protobuf::uint32, bool> p = input->ReadTagWithCutoffNoLastTag(127u);
    tag = p.first;
    if (!p.second) goto handle_unusual;
    switch (::google::protobuf::internal::WireFormatLite::GetTagFieldNumber(tag)) {
      // .ubii.processing.ProcessingMode.Frequency frequency = 1;
      case 1: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(10u /* 10 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadMessage(
               input, mutable_frequency()));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // .ubii.processing.ProcessingMode.Lockstep lockstep = 2;
      case 2: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(18u /* 18 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadMessage(
               input, mutable_lockstep()));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // .ubii.processing.ProcessingMode.TriggerOnInput trigger_on_input = 3;
      case 3: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(26u /* 26 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadMessage(
               input, mutable_trigger_on_input()));
        } else {
          goto handle_unusual;
        }
        break;
      }

      default: {
      handle_unusual:
        if (tag == 0) {
          goto success;
        }
        DO_(::google::protobuf::internal::WireFormat::SkipField(
              input, tag, _internal_metadata_.mutable_unknown_fields()));
        break;
      }
    }
  }
success:
  // @@protoc_insertion_point(parse_success:ubii.processing.ProcessingMode)
  return true;
failure:
  // @@protoc_insertion_point(parse_failure:ubii.processing.ProcessingMode)
  return false;
#undef DO_
}

void ProcessingMode::SerializeWithCachedSizes(
    ::google::protobuf::io::CodedOutputStream* output) const {
  // @@protoc_insertion_point(serialize_start:ubii.processing.ProcessingMode)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // .ubii.processing.ProcessingMode.Frequency frequency = 1;
  if (has_frequency()) {
    ::google::protobuf::internal::WireFormatLite::WriteMessageMaybeToArray(
      1, this->_internal_frequency(), output);
  }

  // .ubii.processing.ProcessingMode.Lockstep lockstep = 2;
  if (has_lockstep()) {
    ::google::protobuf::internal::WireFormatLite::WriteMessageMaybeToArray(
      2, this->_internal_lockstep(), output);
  }

  // .ubii.processing.ProcessingMode.TriggerOnInput trigger_on_input = 3;
  if (has_trigger_on_input()) {
    ::google::protobuf::internal::WireFormatLite::WriteMessageMaybeToArray(
      3, this->_internal_trigger_on_input(), output);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    ::google::protobuf::internal::WireFormat::SerializeUnknownFields(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), output);
  }
  // @@protoc_insertion_point(serialize_end:ubii.processing.ProcessingMode)
}

::google::protobuf::uint8* ProcessingMode::InternalSerializeWithCachedSizesToArray(
    bool deterministic, ::google::protobuf::uint8* target) const {
  (void)deterministic; // Unused
  // @@protoc_insertion_point(serialize_to_array_start:ubii.processing.ProcessingMode)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // .ubii.processing.ProcessingMode.Frequency frequency = 1;
  if (has_frequency()) {
    target = ::google::protobuf::internal::WireFormatLite::
      InternalWriteMessageToArray(
        1, this->_internal_frequency(), deterministic, target);
  }

  // .ubii.processing.ProcessingMode.Lockstep lockstep = 2;
  if (has_lockstep()) {
    target = ::google::protobuf::internal::WireFormatLite::
      InternalWriteMessageToArray(
        2, this->_internal_lockstep(), deterministic, target);
  }

  // .ubii.processing.ProcessingMode.TriggerOnInput trigger_on_input = 3;
  if (has_trigger_on_input()) {
    target = ::google::protobuf::internal::WireFormatLite::
      InternalWriteMessageToArray(
        3, this->_internal_trigger_on_input(), deterministic, target);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    target = ::google::protobuf::internal::WireFormat::SerializeUnknownFieldsToArray(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:ubii.processing.ProcessingMode)
  return target;
}

size_t ProcessingMode::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:ubii.processing.ProcessingMode)
  size_t total_size = 0;

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    total_size +=
      ::google::protobuf::internal::WireFormat::ComputeUnknownFieldsSize(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()));
  }
  switch (mode_case()) {
    // .ubii.processing.ProcessingMode.Frequency frequency = 1;
    case kFrequency: {
      total_size += 1 +
        ::google::protobuf::internal::WireFormatLite::MessageSize(
          *mode_.frequency_);
      break;
    }
    // .ubii.processing.ProcessingMode.Lockstep lockstep = 2;
    case kLockstep: {
      total_size += 1 +
        ::google::protobuf::internal::WireFormatLite::MessageSize(
          *mode_.lockstep_);
      break;
    }
    // .ubii.processing.ProcessingMode.TriggerOnInput trigger_on_input = 3;
    case kTriggerOnInput: {
      total_size += 1 +
        ::google::protobuf::internal::WireFormatLite::MessageSize(
          *mode_.trigger_on_input_);
      break;
    }
    case MODE_NOT_SET: {
      break;
    }
  }
  int cached_size = ::google::protobuf::internal::ToCachedSize(total_size);
  SetCachedSize(cached_size);
  return total_size;
}

void ProcessingMode::MergeFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_merge_from_start:ubii.processing.ProcessingMode)
  GOOGLE_DCHECK_NE(&from, this);
  const ProcessingMode* source =
      ::google::protobuf::internal::DynamicCastToGenerated<const ProcessingMode>(
          &from);
  if (source == NULL) {
  // @@protoc_insertion_point(generalized_merge_from_cast_fail:ubii.processing.ProcessingMode)
    ::google::protobuf::internal::ReflectionOps::Merge(from, this);
  } else {
  // @@protoc_insertion_point(generalized_merge_from_cast_success:ubii.processing.ProcessingMode)
    MergeFrom(*source);
  }
}

void ProcessingMode::MergeFrom(const ProcessingMode& from) {
// @@protoc_insertion_point(class_specific_merge_from_start:ubii.processing.ProcessingMode)
  GOOGLE_DCHECK_NE(&from, this);
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  switch (from.mode_case()) {
    case kFrequency: {
      mutable_frequency()->::ubii::processing::ProcessingMode_Frequency::MergeFrom(from.frequency());
      break;
    }
    case kLockstep: {
      mutable_lockstep()->::ubii::processing::ProcessingMode_Lockstep::MergeFrom(from.lockstep());
      break;
    }
    case kTriggerOnInput: {
      mutable_trigger_on_input()->::ubii::processing::ProcessingMode_TriggerOnInput::MergeFrom(from.trigger_on_input());
      break;
    }
    case MODE_NOT_SET: {
      break;
    }
  }
}

void ProcessingMode::CopyFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_copy_from_start:ubii.processing.ProcessingMode)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

void ProcessingMode::CopyFrom(const ProcessingMode& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:ubii.processing.ProcessingMode)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool ProcessingMode::IsInitialized() const {
  return true;
}

void ProcessingMode::Swap(ProcessingMode* other) {
  if (other == this) return;
  InternalSwap(other);
}
void ProcessingMode::InternalSwap(ProcessingMode* other) {
  using std::swap;
  swap(mode_, other->mode_);
  swap(_oneof_case_[0], other->_oneof_case_[0]);
  _internal_metadata_.Swap(&other->_internal_metadata_);
}

::google::protobuf::Metadata ProcessingMode::GetMetadata() const {
  protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages];
}


// ===================================================================

void ModuleIO::InitAsDefaultInstance() {
}
#if !defined(_MSC_VER) || _MSC_VER >= 1900
const int ModuleIO::kInternalNameFieldNumber;
const int ModuleIO::kMessageFormatFieldNumber;
#endif  // !defined(_MSC_VER) || _MSC_VER >= 1900

ModuleIO::ModuleIO()
  : ::google::protobuf::Message(), _internal_metadata_(NULL) {
  ::google::protobuf::internal::InitSCC(
      &protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ModuleIO.base);
  SharedCtor();
  // @@protoc_insertion_point(constructor:ubii.processing.ModuleIO)
}
ModuleIO::ModuleIO(const ModuleIO& from)
  : ::google::protobuf::Message(),
      _internal_metadata_(NULL) {
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  internal_name_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (from.internal_name().size() > 0) {
    internal_name_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.internal_name_);
  }
  message_format_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (from.message_format().size() > 0) {
    message_format_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.message_format_);
  }
  // @@protoc_insertion_point(copy_constructor:ubii.processing.ModuleIO)
}

void ModuleIO::SharedCtor() {
  internal_name_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  message_format_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}

ModuleIO::~ModuleIO() {
  // @@protoc_insertion_point(destructor:ubii.processing.ModuleIO)
  SharedDtor();
}

void ModuleIO::SharedDtor() {
  internal_name_.DestroyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  message_format_.DestroyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
}

void ModuleIO::SetCachedSize(int size) const {
  _cached_size_.Set(size);
}
const ::google::protobuf::Descriptor* ModuleIO::descriptor() {
  ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages].descriptor;
}

const ModuleIO& ModuleIO::default_instance() {
  ::google::protobuf::internal::InitSCC(&protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ModuleIO.base);
  return *internal_default_instance();
}


void ModuleIO::Clear() {
// @@protoc_insertion_point(message_clear_start:ubii.processing.ModuleIO)
  ::google::protobuf::uint32 cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  internal_name_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  message_format_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  _internal_metadata_.Clear();
}

bool ModuleIO::MergePartialFromCodedStream(
    ::google::protobuf::io::CodedInputStream* input) {
#define DO_(EXPRESSION) if (!GOOGLE_PREDICT_TRUE(EXPRESSION)) goto failure
  ::google::protobuf::uint32 tag;
  // @@protoc_insertion_point(parse_start:ubii.processing.ModuleIO)
  for (;;) {
    ::std::pair<::google::protobuf::uint32, bool> p = input->ReadTagWithCutoffNoLastTag(127u);
    tag = p.first;
    if (!p.second) goto handle_unusual;
    switch (::google::protobuf::internal::WireFormatLite::GetTagFieldNumber(tag)) {
      // string internal_name = 1;
      case 1: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(10u /* 10 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->mutable_internal_name()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->internal_name().data(), static_cast<int>(this->internal_name().length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ModuleIO.internal_name"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // string message_format = 2;
      case 2: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(18u /* 18 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->mutable_message_format()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->message_format().data(), static_cast<int>(this->message_format().length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ModuleIO.message_format"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      default: {
      handle_unusual:
        if (tag == 0) {
          goto success;
        }
        DO_(::google::protobuf::internal::WireFormat::SkipField(
              input, tag, _internal_metadata_.mutable_unknown_fields()));
        break;
      }
    }
  }
success:
  // @@protoc_insertion_point(parse_success:ubii.processing.ModuleIO)
  return true;
failure:
  // @@protoc_insertion_point(parse_failure:ubii.processing.ModuleIO)
  return false;
#undef DO_
}

void ModuleIO::SerializeWithCachedSizes(
    ::google::protobuf::io::CodedOutputStream* output) const {
  // @@protoc_insertion_point(serialize_start:ubii.processing.ModuleIO)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // string internal_name = 1;
  if (this->internal_name().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->internal_name().data(), static_cast<int>(this->internal_name().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ModuleIO.internal_name");
    ::google::protobuf::internal::WireFormatLite::WriteStringMaybeAliased(
      1, this->internal_name(), output);
  }

  // string message_format = 2;
  if (this->message_format().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->message_format().data(), static_cast<int>(this->message_format().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ModuleIO.message_format");
    ::google::protobuf::internal::WireFormatLite::WriteStringMaybeAliased(
      2, this->message_format(), output);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    ::google::protobuf::internal::WireFormat::SerializeUnknownFields(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), output);
  }
  // @@protoc_insertion_point(serialize_end:ubii.processing.ModuleIO)
}

::google::protobuf::uint8* ModuleIO::InternalSerializeWithCachedSizesToArray(
    bool deterministic, ::google::protobuf::uint8* target) const {
  (void)deterministic; // Unused
  // @@protoc_insertion_point(serialize_to_array_start:ubii.processing.ModuleIO)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // string internal_name = 1;
  if (this->internal_name().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->internal_name().data(), static_cast<int>(this->internal_name().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ModuleIO.internal_name");
    target =
      ::google::protobuf::internal::WireFormatLite::WriteStringToArray(
        1, this->internal_name(), target);
  }

  // string message_format = 2;
  if (this->message_format().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->message_format().data(), static_cast<int>(this->message_format().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ModuleIO.message_format");
    target =
      ::google::protobuf::internal::WireFormatLite::WriteStringToArray(
        2, this->message_format(), target);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    target = ::google::protobuf::internal::WireFormat::SerializeUnknownFieldsToArray(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:ubii.processing.ModuleIO)
  return target;
}

size_t ModuleIO::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:ubii.processing.ModuleIO)
  size_t total_size = 0;

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    total_size +=
      ::google::protobuf::internal::WireFormat::ComputeUnknownFieldsSize(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()));
  }
  // string internal_name = 1;
  if (this->internal_name().size() > 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::StringSize(
        this->internal_name());
  }

  // string message_format = 2;
  if (this->message_format().size() > 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::StringSize(
        this->message_format());
  }

  int cached_size = ::google::protobuf::internal::ToCachedSize(total_size);
  SetCachedSize(cached_size);
  return total_size;
}

void ModuleIO::MergeFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_merge_from_start:ubii.processing.ModuleIO)
  GOOGLE_DCHECK_NE(&from, this);
  const ModuleIO* source =
      ::google::protobuf::internal::DynamicCastToGenerated<const ModuleIO>(
          &from);
  if (source == NULL) {
  // @@protoc_insertion_point(generalized_merge_from_cast_fail:ubii.processing.ModuleIO)
    ::google::protobuf::internal::ReflectionOps::Merge(from, this);
  } else {
  // @@protoc_insertion_point(generalized_merge_from_cast_success:ubii.processing.ModuleIO)
    MergeFrom(*source);
  }
}

void ModuleIO::MergeFrom(const ModuleIO& from) {
// @@protoc_insertion_point(class_specific_merge_from_start:ubii.processing.ModuleIO)
  GOOGLE_DCHECK_NE(&from, this);
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  if (from.internal_name().size() > 0) {

    internal_name_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.internal_name_);
  }
  if (from.message_format().size() > 0) {

    message_format_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.message_format_);
  }
}

void ModuleIO::CopyFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_copy_from_start:ubii.processing.ModuleIO)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

void ModuleIO::CopyFrom(const ModuleIO& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:ubii.processing.ModuleIO)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool ModuleIO::IsInitialized() const {
  return true;
}

void ModuleIO::Swap(ModuleIO* other) {
  if (other == this) return;
  InternalSwap(other);
}
void ModuleIO::InternalSwap(ModuleIO* other) {
  using std::swap;
  internal_name_.Swap(&other->internal_name_, &::google::protobuf::internal::GetEmptyStringAlreadyInited(),
    GetArenaNoVirtual());
  message_format_.Swap(&other->message_format_, &::google::protobuf::internal::GetEmptyStringAlreadyInited(),
    GetArenaNoVirtual());
  _internal_metadata_.Swap(&other->_internal_metadata_);
}

::google::protobuf::Metadata ModuleIO::GetMetadata() const {
  protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages];
}


// ===================================================================

void ProcessingModule::InitAsDefaultInstance() {
  ::ubii::processing::_ProcessingModule_default_instance_._instance.get_mutable()->processing_mode_ = const_cast< ::ubii::processing::ProcessingMode*>(
      ::ubii::processing::ProcessingMode::internal_default_instance());
}
#if !defined(_MSC_VER) || _MSC_VER >= 1900
const int ProcessingModule::kIdFieldNumber;
const int ProcessingModule::kNameFieldNumber;
const int ProcessingModule::kAuthorsFieldNumber;
const int ProcessingModule::kTagsFieldNumber;
const int ProcessingModule::kDescriptionFieldNumber;
const int ProcessingModule::kNodeIdFieldNumber;
const int ProcessingModule::kSessionIdFieldNumber;
const int ProcessingModule::kStatusFieldNumber;
const int ProcessingModule::kProcessingModeFieldNumber;
const int ProcessingModule::kInputsFieldNumber;
const int ProcessingModule::kOutputsFieldNumber;
const int ProcessingModule::kLanguageFieldNumber;
const int ProcessingModule::kOnProcessingStringifiedFieldNumber;
const int ProcessingModule::kOnCreatedStringifiedFieldNumber;
const int ProcessingModule::kOnHaltedStringifiedFieldNumber;
const int ProcessingModule::kOnDestroyedStringifiedFieldNumber;
#endif  // !defined(_MSC_VER) || _MSC_VER >= 1900

ProcessingModule::ProcessingModule()
  : ::google::protobuf::Message(), _internal_metadata_(NULL) {
  ::google::protobuf::internal::InitSCC(
      &protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingModule.base);
  SharedCtor();
  // @@protoc_insertion_point(constructor:ubii.processing.ProcessingModule)
}
ProcessingModule::ProcessingModule(const ProcessingModule& from)
  : ::google::protobuf::Message(),
      _internal_metadata_(NULL),
      authors_(from.authors_),
      tags_(from.tags_),
      inputs_(from.inputs_),
      outputs_(from.outputs_) {
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  id_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (from.id().size() > 0) {
    id_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.id_);
  }
  name_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (from.name().size() > 0) {
    name_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.name_);
  }
  description_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (from.description().size() > 0) {
    description_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.description_);
  }
  node_id_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (from.node_id().size() > 0) {
    node_id_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.node_id_);
  }
  session_id_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (from.session_id().size() > 0) {
    session_id_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.session_id_);
  }
  on_processing_stringified_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (from.on_processing_stringified().size() > 0) {
    on_processing_stringified_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.on_processing_stringified_);
  }
  on_created_stringified_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (from.on_created_stringified().size() > 0) {
    on_created_stringified_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.on_created_stringified_);
  }
  on_halted_stringified_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (from.on_halted_stringified().size() > 0) {
    on_halted_stringified_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.on_halted_stringified_);
  }
  on_destroyed_stringified_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (from.on_destroyed_stringified().size() > 0) {
    on_destroyed_stringified_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.on_destroyed_stringified_);
  }
  if (from.has_processing_mode()) {
    processing_mode_ = new ::ubii::processing::ProcessingMode(*from.processing_mode_);
  } else {
    processing_mode_ = NULL;
  }
  ::memcpy(&status_, &from.status_,
    static_cast<size_t>(reinterpret_cast<char*>(&language_) -
    reinterpret_cast<char*>(&status_)) + sizeof(language_));
  // @@protoc_insertion_point(copy_constructor:ubii.processing.ProcessingModule)
}

void ProcessingModule::SharedCtor() {
  id_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  name_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  description_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  node_id_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  session_id_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  on_processing_stringified_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  on_created_stringified_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  on_halted_stringified_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  on_destroyed_stringified_.UnsafeSetDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  ::memset(&processing_mode_, 0, static_cast<size_t>(
      reinterpret_cast<char*>(&language_) -
      reinterpret_cast<char*>(&processing_mode_)) + sizeof(language_));
}

ProcessingModule::~ProcessingModule() {
  // @@protoc_insertion_point(destructor:ubii.processing.ProcessingModule)
  SharedDtor();
}

void ProcessingModule::SharedDtor() {
  id_.DestroyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  name_.DestroyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  description_.DestroyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  node_id_.DestroyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  session_id_.DestroyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  on_processing_stringified_.DestroyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  on_created_stringified_.DestroyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  on_halted_stringified_.DestroyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  on_destroyed_stringified_.DestroyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (this != internal_default_instance()) delete processing_mode_;
}

void ProcessingModule::SetCachedSize(int size) const {
  _cached_size_.Set(size);
}
const ::google::protobuf::Descriptor* ProcessingModule::descriptor() {
  ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages].descriptor;
}

const ProcessingModule& ProcessingModule::default_instance() {
  ::google::protobuf::internal::InitSCC(&protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingModule.base);
  return *internal_default_instance();
}


void ProcessingModule::Clear() {
// @@protoc_insertion_point(message_clear_start:ubii.processing.ProcessingModule)
  ::google::protobuf::uint32 cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  authors_.Clear();
  tags_.Clear();
  inputs_.Clear();
  outputs_.Clear();
  id_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  name_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  description_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  node_id_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  session_id_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  on_processing_stringified_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  on_created_stringified_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  on_halted_stringified_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  on_destroyed_stringified_.ClearToEmptyNoArena(&::google::protobuf::internal::GetEmptyStringAlreadyInited());
  if (GetArenaNoVirtual() == NULL && processing_mode_ != NULL) {
    delete processing_mode_;
  }
  processing_mode_ = NULL;
  ::memset(&status_, 0, static_cast<size_t>(
      reinterpret_cast<char*>(&language_) -
      reinterpret_cast<char*>(&status_)) + sizeof(language_));
  _internal_metadata_.Clear();
}

bool ProcessingModule::MergePartialFromCodedStream(
    ::google::protobuf::io::CodedInputStream* input) {
#define DO_(EXPRESSION) if (!GOOGLE_PREDICT_TRUE(EXPRESSION)) goto failure
  ::google::protobuf::uint32 tag;
  // @@protoc_insertion_point(parse_start:ubii.processing.ProcessingModule)
  for (;;) {
    ::std::pair<::google::protobuf::uint32, bool> p = input->ReadTagWithCutoffNoLastTag(16383u);
    tag = p.first;
    if (!p.second) goto handle_unusual;
    switch (::google::protobuf::internal::WireFormatLite::GetTagFieldNumber(tag)) {
      // string id = 1;
      case 1: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(10u /* 10 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->mutable_id()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->id().data(), static_cast<int>(this->id().length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ProcessingModule.id"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // string name = 2;
      case 2: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(18u /* 18 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->mutable_name()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->name().data(), static_cast<int>(this->name().length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ProcessingModule.name"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // repeated string authors = 3;
      case 3: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(26u /* 26 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->add_authors()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->authors(this->authors_size() - 1).data(),
            static_cast<int>(this->authors(this->authors_size() - 1).length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ProcessingModule.authors"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // repeated string tags = 4;
      case 4: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(34u /* 34 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->add_tags()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->tags(this->tags_size() - 1).data(),
            static_cast<int>(this->tags(this->tags_size() - 1).length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ProcessingModule.tags"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // string description = 5;
      case 5: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(42u /* 42 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->mutable_description()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->description().data(), static_cast<int>(this->description().length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ProcessingModule.description"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // string node_id = 6;
      case 6: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(50u /* 50 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->mutable_node_id()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->node_id().data(), static_cast<int>(this->node_id().length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ProcessingModule.node_id"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // string session_id = 7;
      case 7: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(58u /* 58 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->mutable_session_id()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->session_id().data(), static_cast<int>(this->session_id().length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ProcessingModule.session_id"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // .ubii.processing.ProcessingModule.Status status = 8;
      case 8: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(64u /* 64 & 0xFF */)) {
          int value;
          DO_((::google::protobuf::internal::WireFormatLite::ReadPrimitive<
                   int, ::google::protobuf::internal::WireFormatLite::TYPE_ENUM>(
                 input, &value)));
          set_status(static_cast< ::ubii::processing::ProcessingModule_Status >(value));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // .ubii.processing.ProcessingMode processing_mode = 9;
      case 9: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(74u /* 74 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadMessage(
               input, mutable_processing_mode()));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // repeated .ubii.processing.ModuleIO inputs = 10;
      case 10: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(82u /* 82 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadMessage(
                input, add_inputs()));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // repeated .ubii.processing.ModuleIO outputs = 11;
      case 11: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(90u /* 90 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadMessage(
                input, add_outputs()));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // .ubii.processing.ProcessingModule.Language language = 12;
      case 12: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(96u /* 96 & 0xFF */)) {
          int value;
          DO_((::google::protobuf::internal::WireFormatLite::ReadPrimitive<
                   int, ::google::protobuf::internal::WireFormatLite::TYPE_ENUM>(
                 input, &value)));
          set_language(static_cast< ::ubii::processing::ProcessingModule_Language >(value));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // string on_processing_stringified = 13;
      case 13: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(106u /* 106 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->mutable_on_processing_stringified()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->on_processing_stringified().data(), static_cast<int>(this->on_processing_stringified().length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ProcessingModule.on_processing_stringified"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // string on_created_stringified = 14;
      case 14: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(114u /* 114 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->mutable_on_created_stringified()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->on_created_stringified().data(), static_cast<int>(this->on_created_stringified().length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ProcessingModule.on_created_stringified"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // string on_halted_stringified = 15;
      case 15: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(122u /* 122 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->mutable_on_halted_stringified()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->on_halted_stringified().data(), static_cast<int>(this->on_halted_stringified().length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ProcessingModule.on_halted_stringified"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      // string on_destroyed_stringified = 16;
      case 16: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(130u /* 130 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadString(
                input, this->mutable_on_destroyed_stringified()));
          DO_(::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
            this->on_destroyed_stringified().data(), static_cast<int>(this->on_destroyed_stringified().length()),
            ::google::protobuf::internal::WireFormatLite::PARSE,
            "ubii.processing.ProcessingModule.on_destroyed_stringified"));
        } else {
          goto handle_unusual;
        }
        break;
      }

      default: {
      handle_unusual:
        if (tag == 0) {
          goto success;
        }
        DO_(::google::protobuf::internal::WireFormat::SkipField(
              input, tag, _internal_metadata_.mutable_unknown_fields()));
        break;
      }
    }
  }
success:
  // @@protoc_insertion_point(parse_success:ubii.processing.ProcessingModule)
  return true;
failure:
  // @@protoc_insertion_point(parse_failure:ubii.processing.ProcessingModule)
  return false;
#undef DO_
}

void ProcessingModule::SerializeWithCachedSizes(
    ::google::protobuf::io::CodedOutputStream* output) const {
  // @@protoc_insertion_point(serialize_start:ubii.processing.ProcessingModule)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // string id = 1;
  if (this->id().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->id().data(), static_cast<int>(this->id().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.id");
    ::google::protobuf::internal::WireFormatLite::WriteStringMaybeAliased(
      1, this->id(), output);
  }

  // string name = 2;
  if (this->name().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->name().data(), static_cast<int>(this->name().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.name");
    ::google::protobuf::internal::WireFormatLite::WriteStringMaybeAliased(
      2, this->name(), output);
  }

  // repeated string authors = 3;
  for (int i = 0, n = this->authors_size(); i < n; i++) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->authors(i).data(), static_cast<int>(this->authors(i).length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.authors");
    ::google::protobuf::internal::WireFormatLite::WriteString(
      3, this->authors(i), output);
  }

  // repeated string tags = 4;
  for (int i = 0, n = this->tags_size(); i < n; i++) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->tags(i).data(), static_cast<int>(this->tags(i).length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.tags");
    ::google::protobuf::internal::WireFormatLite::WriteString(
      4, this->tags(i), output);
  }

  // string description = 5;
  if (this->description().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->description().data(), static_cast<int>(this->description().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.description");
    ::google::protobuf::internal::WireFormatLite::WriteStringMaybeAliased(
      5, this->description(), output);
  }

  // string node_id = 6;
  if (this->node_id().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->node_id().data(), static_cast<int>(this->node_id().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.node_id");
    ::google::protobuf::internal::WireFormatLite::WriteStringMaybeAliased(
      6, this->node_id(), output);
  }

  // string session_id = 7;
  if (this->session_id().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->session_id().data(), static_cast<int>(this->session_id().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.session_id");
    ::google::protobuf::internal::WireFormatLite::WriteStringMaybeAliased(
      7, this->session_id(), output);
  }

  // .ubii.processing.ProcessingModule.Status status = 8;
  if (this->status() != 0) {
    ::google::protobuf::internal::WireFormatLite::WriteEnum(
      8, this->status(), output);
  }

  // .ubii.processing.ProcessingMode processing_mode = 9;
  if (this->has_processing_mode()) {
    ::google::protobuf::internal::WireFormatLite::WriteMessageMaybeToArray(
      9, this->_internal_processing_mode(), output);
  }

  // repeated .ubii.processing.ModuleIO inputs = 10;
  for (unsigned int i = 0,
      n = static_cast<unsigned int>(this->inputs_size()); i < n; i++) {
    ::google::protobuf::internal::WireFormatLite::WriteMessageMaybeToArray(
      10,
      this->inputs(static_cast<int>(i)),
      output);
  }

  // repeated .ubii.processing.ModuleIO outputs = 11;
  for (unsigned int i = 0,
      n = static_cast<unsigned int>(this->outputs_size()); i < n; i++) {
    ::google::protobuf::internal::WireFormatLite::WriteMessageMaybeToArray(
      11,
      this->outputs(static_cast<int>(i)),
      output);
  }

  // .ubii.processing.ProcessingModule.Language language = 12;
  if (this->language() != 0) {
    ::google::protobuf::internal::WireFormatLite::WriteEnum(
      12, this->language(), output);
  }

  // string on_processing_stringified = 13;
  if (this->on_processing_stringified().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->on_processing_stringified().data(), static_cast<int>(this->on_processing_stringified().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.on_processing_stringified");
    ::google::protobuf::internal::WireFormatLite::WriteStringMaybeAliased(
      13, this->on_processing_stringified(), output);
  }

  // string on_created_stringified = 14;
  if (this->on_created_stringified().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->on_created_stringified().data(), static_cast<int>(this->on_created_stringified().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.on_created_stringified");
    ::google::protobuf::internal::WireFormatLite::WriteStringMaybeAliased(
      14, this->on_created_stringified(), output);
  }

  // string on_halted_stringified = 15;
  if (this->on_halted_stringified().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->on_halted_stringified().data(), static_cast<int>(this->on_halted_stringified().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.on_halted_stringified");
    ::google::protobuf::internal::WireFormatLite::WriteStringMaybeAliased(
      15, this->on_halted_stringified(), output);
  }

  // string on_destroyed_stringified = 16;
  if (this->on_destroyed_stringified().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->on_destroyed_stringified().data(), static_cast<int>(this->on_destroyed_stringified().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.on_destroyed_stringified");
    ::google::protobuf::internal::WireFormatLite::WriteStringMaybeAliased(
      16, this->on_destroyed_stringified(), output);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    ::google::protobuf::internal::WireFormat::SerializeUnknownFields(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), output);
  }
  // @@protoc_insertion_point(serialize_end:ubii.processing.ProcessingModule)
}

::google::protobuf::uint8* ProcessingModule::InternalSerializeWithCachedSizesToArray(
    bool deterministic, ::google::protobuf::uint8* target) const {
  (void)deterministic; // Unused
  // @@protoc_insertion_point(serialize_to_array_start:ubii.processing.ProcessingModule)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // string id = 1;
  if (this->id().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->id().data(), static_cast<int>(this->id().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.id");
    target =
      ::google::protobuf::internal::WireFormatLite::WriteStringToArray(
        1, this->id(), target);
  }

  // string name = 2;
  if (this->name().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->name().data(), static_cast<int>(this->name().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.name");
    target =
      ::google::protobuf::internal::WireFormatLite::WriteStringToArray(
        2, this->name(), target);
  }

  // repeated string authors = 3;
  for (int i = 0, n = this->authors_size(); i < n; i++) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->authors(i).data(), static_cast<int>(this->authors(i).length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.authors");
    target = ::google::protobuf::internal::WireFormatLite::
      WriteStringToArray(3, this->authors(i), target);
  }

  // repeated string tags = 4;
  for (int i = 0, n = this->tags_size(); i < n; i++) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->tags(i).data(), static_cast<int>(this->tags(i).length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.tags");
    target = ::google::protobuf::internal::WireFormatLite::
      WriteStringToArray(4, this->tags(i), target);
  }

  // string description = 5;
  if (this->description().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->description().data(), static_cast<int>(this->description().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.description");
    target =
      ::google::protobuf::internal::WireFormatLite::WriteStringToArray(
        5, this->description(), target);
  }

  // string node_id = 6;
  if (this->node_id().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->node_id().data(), static_cast<int>(this->node_id().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.node_id");
    target =
      ::google::protobuf::internal::WireFormatLite::WriteStringToArray(
        6, this->node_id(), target);
  }

  // string session_id = 7;
  if (this->session_id().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->session_id().data(), static_cast<int>(this->session_id().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.session_id");
    target =
      ::google::protobuf::internal::WireFormatLite::WriteStringToArray(
        7, this->session_id(), target);
  }

  // .ubii.processing.ProcessingModule.Status status = 8;
  if (this->status() != 0) {
    target = ::google::protobuf::internal::WireFormatLite::WriteEnumToArray(
      8, this->status(), target);
  }

  // .ubii.processing.ProcessingMode processing_mode = 9;
  if (this->has_processing_mode()) {
    target = ::google::protobuf::internal::WireFormatLite::
      InternalWriteMessageToArray(
        9, this->_internal_processing_mode(), deterministic, target);
  }

  // repeated .ubii.processing.ModuleIO inputs = 10;
  for (unsigned int i = 0,
      n = static_cast<unsigned int>(this->inputs_size()); i < n; i++) {
    target = ::google::protobuf::internal::WireFormatLite::
      InternalWriteMessageToArray(
        10, this->inputs(static_cast<int>(i)), deterministic, target);
  }

  // repeated .ubii.processing.ModuleIO outputs = 11;
  for (unsigned int i = 0,
      n = static_cast<unsigned int>(this->outputs_size()); i < n; i++) {
    target = ::google::protobuf::internal::WireFormatLite::
      InternalWriteMessageToArray(
        11, this->outputs(static_cast<int>(i)), deterministic, target);
  }

  // .ubii.processing.ProcessingModule.Language language = 12;
  if (this->language() != 0) {
    target = ::google::protobuf::internal::WireFormatLite::WriteEnumToArray(
      12, this->language(), target);
  }

  // string on_processing_stringified = 13;
  if (this->on_processing_stringified().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->on_processing_stringified().data(), static_cast<int>(this->on_processing_stringified().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.on_processing_stringified");
    target =
      ::google::protobuf::internal::WireFormatLite::WriteStringToArray(
        13, this->on_processing_stringified(), target);
  }

  // string on_created_stringified = 14;
  if (this->on_created_stringified().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->on_created_stringified().data(), static_cast<int>(this->on_created_stringified().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.on_created_stringified");
    target =
      ::google::protobuf::internal::WireFormatLite::WriteStringToArray(
        14, this->on_created_stringified(), target);
  }

  // string on_halted_stringified = 15;
  if (this->on_halted_stringified().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->on_halted_stringified().data(), static_cast<int>(this->on_halted_stringified().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.on_halted_stringified");
    target =
      ::google::protobuf::internal::WireFormatLite::WriteStringToArray(
        15, this->on_halted_stringified(), target);
  }

  // string on_destroyed_stringified = 16;
  if (this->on_destroyed_stringified().size() > 0) {
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
      this->on_destroyed_stringified().data(), static_cast<int>(this->on_destroyed_stringified().length()),
      ::google::protobuf::internal::WireFormatLite::SERIALIZE,
      "ubii.processing.ProcessingModule.on_destroyed_stringified");
    target =
      ::google::protobuf::internal::WireFormatLite::WriteStringToArray(
        16, this->on_destroyed_stringified(), target);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    target = ::google::protobuf::internal::WireFormat::SerializeUnknownFieldsToArray(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:ubii.processing.ProcessingModule)
  return target;
}

size_t ProcessingModule::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:ubii.processing.ProcessingModule)
  size_t total_size = 0;

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    total_size +=
      ::google::protobuf::internal::WireFormat::ComputeUnknownFieldsSize(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()));
  }
  // repeated string authors = 3;
  total_size += 1 *
      ::google::protobuf::internal::FromIntSize(this->authors_size());
  for (int i = 0, n = this->authors_size(); i < n; i++) {
    total_size += ::google::protobuf::internal::WireFormatLite::StringSize(
      this->authors(i));
  }

  // repeated string tags = 4;
  total_size += 1 *
      ::google::protobuf::internal::FromIntSize(this->tags_size());
  for (int i = 0, n = this->tags_size(); i < n; i++) {
    total_size += ::google::protobuf::internal::WireFormatLite::StringSize(
      this->tags(i));
  }

  // repeated .ubii.processing.ModuleIO inputs = 10;
  {
    unsigned int count = static_cast<unsigned int>(this->inputs_size());
    total_size += 1UL * count;
    for (unsigned int i = 0; i < count; i++) {
      total_size +=
        ::google::protobuf::internal::WireFormatLite::MessageSize(
          this->inputs(static_cast<int>(i)));
    }
  }

  // repeated .ubii.processing.ModuleIO outputs = 11;
  {
    unsigned int count = static_cast<unsigned int>(this->outputs_size());
    total_size += 1UL * count;
    for (unsigned int i = 0; i < count; i++) {
      total_size +=
        ::google::protobuf::internal::WireFormatLite::MessageSize(
          this->outputs(static_cast<int>(i)));
    }
  }

  // string id = 1;
  if (this->id().size() > 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::StringSize(
        this->id());
  }

  // string name = 2;
  if (this->name().size() > 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::StringSize(
        this->name());
  }

  // string description = 5;
  if (this->description().size() > 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::StringSize(
        this->description());
  }

  // string node_id = 6;
  if (this->node_id().size() > 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::StringSize(
        this->node_id());
  }

  // string session_id = 7;
  if (this->session_id().size() > 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::StringSize(
        this->session_id());
  }

  // string on_processing_stringified = 13;
  if (this->on_processing_stringified().size() > 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::StringSize(
        this->on_processing_stringified());
  }

  // string on_created_stringified = 14;
  if (this->on_created_stringified().size() > 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::StringSize(
        this->on_created_stringified());
  }

  // string on_halted_stringified = 15;
  if (this->on_halted_stringified().size() > 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::StringSize(
        this->on_halted_stringified());
  }

  // string on_destroyed_stringified = 16;
  if (this->on_destroyed_stringified().size() > 0) {
    total_size += 2 +
      ::google::protobuf::internal::WireFormatLite::StringSize(
        this->on_destroyed_stringified());
  }

  // .ubii.processing.ProcessingMode processing_mode = 9;
  if (this->has_processing_mode()) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::MessageSize(
        *processing_mode_);
  }

  // .ubii.processing.ProcessingModule.Status status = 8;
  if (this->status() != 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::EnumSize(this->status());
  }

  // .ubii.processing.ProcessingModule.Language language = 12;
  if (this->language() != 0) {
    total_size += 1 +
      ::google::protobuf::internal::WireFormatLite::EnumSize(this->language());
  }

  int cached_size = ::google::protobuf::internal::ToCachedSize(total_size);
  SetCachedSize(cached_size);
  return total_size;
}

void ProcessingModule::MergeFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_merge_from_start:ubii.processing.ProcessingModule)
  GOOGLE_DCHECK_NE(&from, this);
  const ProcessingModule* source =
      ::google::protobuf::internal::DynamicCastToGenerated<const ProcessingModule>(
          &from);
  if (source == NULL) {
  // @@protoc_insertion_point(generalized_merge_from_cast_fail:ubii.processing.ProcessingModule)
    ::google::protobuf::internal::ReflectionOps::Merge(from, this);
  } else {
  // @@protoc_insertion_point(generalized_merge_from_cast_success:ubii.processing.ProcessingModule)
    MergeFrom(*source);
  }
}

void ProcessingModule::MergeFrom(const ProcessingModule& from) {
// @@protoc_insertion_point(class_specific_merge_from_start:ubii.processing.ProcessingModule)
  GOOGLE_DCHECK_NE(&from, this);
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  authors_.MergeFrom(from.authors_);
  tags_.MergeFrom(from.tags_);
  inputs_.MergeFrom(from.inputs_);
  outputs_.MergeFrom(from.outputs_);
  if (from.id().size() > 0) {

    id_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.id_);
  }
  if (from.name().size() > 0) {

    name_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.name_);
  }
  if (from.description().size() > 0) {

    description_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.description_);
  }
  if (from.node_id().size() > 0) {

    node_id_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.node_id_);
  }
  if (from.session_id().size() > 0) {

    session_id_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.session_id_);
  }
  if (from.on_processing_stringified().size() > 0) {

    on_processing_stringified_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.on_processing_stringified_);
  }
  if (from.on_created_stringified().size() > 0) {

    on_created_stringified_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.on_created_stringified_);
  }
  if (from.on_halted_stringified().size() > 0) {

    on_halted_stringified_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.on_halted_stringified_);
  }
  if (from.on_destroyed_stringified().size() > 0) {

    on_destroyed_stringified_.AssignWithDefault(&::google::protobuf::internal::GetEmptyStringAlreadyInited(), from.on_destroyed_stringified_);
  }
  if (from.has_processing_mode()) {
    mutable_processing_mode()->::ubii::processing::ProcessingMode::MergeFrom(from.processing_mode());
  }
  if (from.status() != 0) {
    set_status(from.status());
  }
  if (from.language() != 0) {
    set_language(from.language());
  }
}

void ProcessingModule::CopyFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_copy_from_start:ubii.processing.ProcessingModule)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

void ProcessingModule::CopyFrom(const ProcessingModule& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:ubii.processing.ProcessingModule)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool ProcessingModule::IsInitialized() const {
  return true;
}

void ProcessingModule::Swap(ProcessingModule* other) {
  if (other == this) return;
  InternalSwap(other);
}
void ProcessingModule::InternalSwap(ProcessingModule* other) {
  using std::swap;
  authors_.InternalSwap(CastToBase(&other->authors_));
  tags_.InternalSwap(CastToBase(&other->tags_));
  CastToBase(&inputs_)->InternalSwap(CastToBase(&other->inputs_));
  CastToBase(&outputs_)->InternalSwap(CastToBase(&other->outputs_));
  id_.Swap(&other->id_, &::google::protobuf::internal::GetEmptyStringAlreadyInited(),
    GetArenaNoVirtual());
  name_.Swap(&other->name_, &::google::protobuf::internal::GetEmptyStringAlreadyInited(),
    GetArenaNoVirtual());
  description_.Swap(&other->description_, &::google::protobuf::internal::GetEmptyStringAlreadyInited(),
    GetArenaNoVirtual());
  node_id_.Swap(&other->node_id_, &::google::protobuf::internal::GetEmptyStringAlreadyInited(),
    GetArenaNoVirtual());
  session_id_.Swap(&other->session_id_, &::google::protobuf::internal::GetEmptyStringAlreadyInited(),
    GetArenaNoVirtual());
  on_processing_stringified_.Swap(&other->on_processing_stringified_, &::google::protobuf::internal::GetEmptyStringAlreadyInited(),
    GetArenaNoVirtual());
  on_created_stringified_.Swap(&other->on_created_stringified_, &::google::protobuf::internal::GetEmptyStringAlreadyInited(),
    GetArenaNoVirtual());
  on_halted_stringified_.Swap(&other->on_halted_stringified_, &::google::protobuf::internal::GetEmptyStringAlreadyInited(),
    GetArenaNoVirtual());
  on_destroyed_stringified_.Swap(&other->on_destroyed_stringified_, &::google::protobuf::internal::GetEmptyStringAlreadyInited(),
    GetArenaNoVirtual());
  swap(processing_mode_, other->processing_mode_);
  swap(status_, other->status_);
  swap(language_, other->language_);
  _internal_metadata_.Swap(&other->_internal_metadata_);
}

::google::protobuf::Metadata ProcessingModule::GetMetadata() const {
  protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages];
}


// ===================================================================

void ProcessingModuleList::InitAsDefaultInstance() {
}
#if !defined(_MSC_VER) || _MSC_VER >= 1900
const int ProcessingModuleList::kElementsFieldNumber;
#endif  // !defined(_MSC_VER) || _MSC_VER >= 1900

ProcessingModuleList::ProcessingModuleList()
  : ::google::protobuf::Message(), _internal_metadata_(NULL) {
  ::google::protobuf::internal::InitSCC(
      &protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingModuleList.base);
  SharedCtor();
  // @@protoc_insertion_point(constructor:ubii.processing.ProcessingModuleList)
}
ProcessingModuleList::ProcessingModuleList(const ProcessingModuleList& from)
  : ::google::protobuf::Message(),
      _internal_metadata_(NULL),
      elements_(from.elements_) {
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  // @@protoc_insertion_point(copy_constructor:ubii.processing.ProcessingModuleList)
}

void ProcessingModuleList::SharedCtor() {
}

ProcessingModuleList::~ProcessingModuleList() {
  // @@protoc_insertion_point(destructor:ubii.processing.ProcessingModuleList)
  SharedDtor();
}

void ProcessingModuleList::SharedDtor() {
}

void ProcessingModuleList::SetCachedSize(int size) const {
  _cached_size_.Set(size);
}
const ::google::protobuf::Descriptor* ProcessingModuleList::descriptor() {
  ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages].descriptor;
}

const ProcessingModuleList& ProcessingModuleList::default_instance() {
  ::google::protobuf::internal::InitSCC(&protobuf_proto_2fprocessing_2fprocessingModule_2eproto::scc_info_ProcessingModuleList.base);
  return *internal_default_instance();
}


void ProcessingModuleList::Clear() {
// @@protoc_insertion_point(message_clear_start:ubii.processing.ProcessingModuleList)
  ::google::protobuf::uint32 cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  elements_.Clear();
  _internal_metadata_.Clear();
}

bool ProcessingModuleList::MergePartialFromCodedStream(
    ::google::protobuf::io::CodedInputStream* input) {
#define DO_(EXPRESSION) if (!GOOGLE_PREDICT_TRUE(EXPRESSION)) goto failure
  ::google::protobuf::uint32 tag;
  // @@protoc_insertion_point(parse_start:ubii.processing.ProcessingModuleList)
  for (;;) {
    ::std::pair<::google::protobuf::uint32, bool> p = input->ReadTagWithCutoffNoLastTag(127u);
    tag = p.first;
    if (!p.second) goto handle_unusual;
    switch (::google::protobuf::internal::WireFormatLite::GetTagFieldNumber(tag)) {
      // repeated .ubii.processing.ProcessingModule elements = 1;
      case 1: {
        if (static_cast< ::google::protobuf::uint8>(tag) ==
            static_cast< ::google::protobuf::uint8>(10u /* 10 & 0xFF */)) {
          DO_(::google::protobuf::internal::WireFormatLite::ReadMessage(
                input, add_elements()));
        } else {
          goto handle_unusual;
        }
        break;
      }

      default: {
      handle_unusual:
        if (tag == 0) {
          goto success;
        }
        DO_(::google::protobuf::internal::WireFormat::SkipField(
              input, tag, _internal_metadata_.mutable_unknown_fields()));
        break;
      }
    }
  }
success:
  // @@protoc_insertion_point(parse_success:ubii.processing.ProcessingModuleList)
  return true;
failure:
  // @@protoc_insertion_point(parse_failure:ubii.processing.ProcessingModuleList)
  return false;
#undef DO_
}

void ProcessingModuleList::SerializeWithCachedSizes(
    ::google::protobuf::io::CodedOutputStream* output) const {
  // @@protoc_insertion_point(serialize_start:ubii.processing.ProcessingModuleList)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // repeated .ubii.processing.ProcessingModule elements = 1;
  for (unsigned int i = 0,
      n = static_cast<unsigned int>(this->elements_size()); i < n; i++) {
    ::google::protobuf::internal::WireFormatLite::WriteMessageMaybeToArray(
      1,
      this->elements(static_cast<int>(i)),
      output);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    ::google::protobuf::internal::WireFormat::SerializeUnknownFields(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), output);
  }
  // @@protoc_insertion_point(serialize_end:ubii.processing.ProcessingModuleList)
}

::google::protobuf::uint8* ProcessingModuleList::InternalSerializeWithCachedSizesToArray(
    bool deterministic, ::google::protobuf::uint8* target) const {
  (void)deterministic; // Unused
  // @@protoc_insertion_point(serialize_to_array_start:ubii.processing.ProcessingModuleList)
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  // repeated .ubii.processing.ProcessingModule elements = 1;
  for (unsigned int i = 0,
      n = static_cast<unsigned int>(this->elements_size()); i < n; i++) {
    target = ::google::protobuf::internal::WireFormatLite::
      InternalWriteMessageToArray(
        1, this->elements(static_cast<int>(i)), deterministic, target);
  }

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    target = ::google::protobuf::internal::WireFormat::SerializeUnknownFieldsToArray(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()), target);
  }
  // @@protoc_insertion_point(serialize_to_array_end:ubii.processing.ProcessingModuleList)
  return target;
}

size_t ProcessingModuleList::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:ubii.processing.ProcessingModuleList)
  size_t total_size = 0;

  if ((_internal_metadata_.have_unknown_fields() &&  ::google::protobuf::internal::GetProto3PreserveUnknownsDefault())) {
    total_size +=
      ::google::protobuf::internal::WireFormat::ComputeUnknownFieldsSize(
        (::google::protobuf::internal::GetProto3PreserveUnknownsDefault()   ? _internal_metadata_.unknown_fields()   : _internal_metadata_.default_instance()));
  }
  // repeated .ubii.processing.ProcessingModule elements = 1;
  {
    unsigned int count = static_cast<unsigned int>(this->elements_size());
    total_size += 1UL * count;
    for (unsigned int i = 0; i < count; i++) {
      total_size +=
        ::google::protobuf::internal::WireFormatLite::MessageSize(
          this->elements(static_cast<int>(i)));
    }
  }

  int cached_size = ::google::protobuf::internal::ToCachedSize(total_size);
  SetCachedSize(cached_size);
  return total_size;
}

void ProcessingModuleList::MergeFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_merge_from_start:ubii.processing.ProcessingModuleList)
  GOOGLE_DCHECK_NE(&from, this);
  const ProcessingModuleList* source =
      ::google::protobuf::internal::DynamicCastToGenerated<const ProcessingModuleList>(
          &from);
  if (source == NULL) {
  // @@protoc_insertion_point(generalized_merge_from_cast_fail:ubii.processing.ProcessingModuleList)
    ::google::protobuf::internal::ReflectionOps::Merge(from, this);
  } else {
  // @@protoc_insertion_point(generalized_merge_from_cast_success:ubii.processing.ProcessingModuleList)
    MergeFrom(*source);
  }
}

void ProcessingModuleList::MergeFrom(const ProcessingModuleList& from) {
// @@protoc_insertion_point(class_specific_merge_from_start:ubii.processing.ProcessingModuleList)
  GOOGLE_DCHECK_NE(&from, this);
  _internal_metadata_.MergeFrom(from._internal_metadata_);
  ::google::protobuf::uint32 cached_has_bits = 0;
  (void) cached_has_bits;

  elements_.MergeFrom(from.elements_);
}

void ProcessingModuleList::CopyFrom(const ::google::protobuf::Message& from) {
// @@protoc_insertion_point(generalized_copy_from_start:ubii.processing.ProcessingModuleList)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

void ProcessingModuleList::CopyFrom(const ProcessingModuleList& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:ubii.processing.ProcessingModuleList)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

bool ProcessingModuleList::IsInitialized() const {
  return true;
}

void ProcessingModuleList::Swap(ProcessingModuleList* other) {
  if (other == this) return;
  InternalSwap(other);
}
void ProcessingModuleList::InternalSwap(ProcessingModuleList* other) {
  using std::swap;
  CastToBase(&elements_)->InternalSwap(CastToBase(&other->elements_));
  _internal_metadata_.Swap(&other->_internal_metadata_);
}

::google::protobuf::Metadata ProcessingModuleList::GetMetadata() const {
  protobuf_proto_2fprocessing_2fprocessingModule_2eproto::protobuf_AssignDescriptorsOnce();
  return ::protobuf_proto_2fprocessing_2fprocessingModule_2eproto::file_level_metadata[kIndexInFileMessages];
}


// @@protoc_insertion_point(namespace_scope)
}  // namespace processing
}  // namespace ubii
namespace google {
namespace protobuf {
template<> GOOGLE_PROTOBUF_ATTRIBUTE_NOINLINE ::ubii::processing::ProcessingMode_Frequency* Arena::CreateMaybeMessage< ::ubii::processing::ProcessingMode_Frequency >(Arena* arena) {
  return Arena::CreateInternal< ::ubii::processing::ProcessingMode_Frequency >(arena);
}
template<> GOOGLE_PROTOBUF_ATTRIBUTE_NOINLINE ::ubii::processing::ProcessingMode_Lockstep* Arena::CreateMaybeMessage< ::ubii::processing::ProcessingMode_Lockstep >(Arena* arena) {
  return Arena::CreateInternal< ::ubii::processing::ProcessingMode_Lockstep >(arena);
}
template<> GOOGLE_PROTOBUF_ATTRIBUTE_NOINLINE ::ubii::processing::ProcessingMode_TriggerOnInput* Arena::CreateMaybeMessage< ::ubii::processing::ProcessingMode_TriggerOnInput >(Arena* arena) {
  return Arena::CreateInternal< ::ubii::processing::ProcessingMode_TriggerOnInput >(arena);
}
template<> GOOGLE_PROTOBUF_ATTRIBUTE_NOINLINE ::ubii::processing::ProcessingMode* Arena::CreateMaybeMessage< ::ubii::processing::ProcessingMode >(Arena* arena) {
  return Arena::CreateInternal< ::ubii::processing::ProcessingMode >(arena);
}
template<> GOOGLE_PROTOBUF_ATTRIBUTE_NOINLINE ::ubii::processing::ModuleIO* Arena::CreateMaybeMessage< ::ubii::processing::ModuleIO >(Arena* arena) {
  return Arena::CreateInternal< ::ubii::processing::ModuleIO >(arena);
}
template<> GOOGLE_PROTOBUF_ATTRIBUTE_NOINLINE ::ubii::processing::ProcessingModule* Arena::CreateMaybeMessage< ::ubii::processing::ProcessingModule >(Arena* arena) {
  return Arena::CreateInternal< ::ubii::processing::ProcessingModule >(arena);
}
template<> GOOGLE_PROTOBUF_ATTRIBUTE_NOINLINE ::ubii::processing::ProcessingModuleList* Arena::CreateMaybeMessage< ::ubii::processing::ProcessingModuleList >(Arena* arena) {
  return Arena::CreateInternal< ::ubii::processing::ProcessingModuleList >(arena);
}
}  // namespace protobuf
}  // namespace google

// @@protoc_insertion_point(global_scope)
